set more off
clear
version 14

global var_interest latitude longitude ///
		occurrence lshock mwshock pol_turmoil ///
		sh_jews sh_jews_credit sh_jews_trd_gr ///
		sh_credit sh_trd_gr no_credit d_sh_jews_credit d_sh_jews_trd_gr
global var_balance rye_suitability ///
		past_occurrence asb_rf sh_lit_jews sh_lit_non_jews ///
		sh_lit_diff sh_catholic urban sh_agr
	
********************************************************************************	
************************ Creates neighbors sample for T2 ***********************
****** ! Keeps only variables that are used in the analysis to save space ******
********************************************************************************

use "$data/data_generated/neighbors_pogrom_data_grid.dta", clear

keep if d_sh_jews_trd_gr == 1 & d_sh_jews_trd_gr_nbr == 0 

gen diff_sh_jews_abs = abs(sh_jews - sh_jews_nbr)
gen diff_d_sh_jews_credit = d_sh_jews_credit - d_sh_jews_credit_nbr
gen diff_d_sh_jews_trd_gr = d_sh_jews_trd_gr - d_sh_jews_trd_gr_nbr

drop if diff_d_sh_jews_credit == 1 & diff_d_sh_jews_trd_gr == -1 | ///
	diff_d_sh_jews_trd_gr == 1 & diff_d_sh_jews_credit == -1
drop diff_d_sh_jews_trd_gr diff_d_sh_jews_credit

preserve
	keep cell_id
	duplicates drop
	
	rename cell_id nbr_cell_id
	
	tempfile list_treat
	save `list_treat', replace
restore

preserve
	merge m:1 nbr_cell_id using `list_treat'
	keep if _merge == 1
	drop _merge 
	
	gen treated = .
	replace treated = 1 if d_sh_jews_credit == 0 & d_sh_jews_credit_nbr == 0 ///
		& d_sh_jews_trd_gr == 1 & d_sh_jews_trd_gr_nbr == 0
	replace treated = 2 if d_sh_jews_credit == 1 & d_sh_jews_credit_nbr == 1 ///
		& d_sh_jews_trd_gr == 1 & d_sh_jews_trd_gr_nbr == 0
	drop if treated == .	
		
	keep cell_id nbr_cell_i year latitude_nbr longitude_nbr ///
		diff_sh_jews treated ///
		occurrence_nbr lshock_nbr mwshock_nbr pol_turmoil_nbr ///
		sh_jews_nbr sh_jews_credit_nbr sh_jews_trd_gr_nbr ///
		sh_credit_nbr sh_trd_gr_nbr no_credit_nbr ///
		d_sh_jews_credit_nbr d_sh_jews_trd_gr_nbr ///
		sh_lit_jews_nbr sh_lit_non_jews_nbr sh_lit_diff_nbr ///
		rye_suitability_nbr asb_rf_nbr ///
		past_occurrence_nbr urban_nbr sh_catholics_nbr sh_agr_nbr
	
	duplicates tag nbr_cell_i year, gen(dup_nbr)		
	gsort cell_id year treated dup_nbr diff_sh_jews_abs

	bys cell_id year: keep if _n == 1
	drop diff_sh_jews treated dup_nbr
	
	tempfile list_match
	save `list_match', replace
	
	rename cell_id cell_id_n
	rename nbr_cell_i cell_id
	rename *_nbr* **
	
	gen treat = 0
					
	tempfile non_treated_neighbors
	save `non_treated_neighbors', replace
restore 

keep cell_id year latitude longitude occurrence lshock mwshock pol_turmoil ///
		sh_jews sh_jews_credit sh_jews_trd_gr ///
		sh_credit sh_trd_gr no_credit d_sh_jews_credit d_sh_jews_trd_gr ///
		sh_lit_jews sh_lit_non_jews sh_lit_diff ///
		rye_suitability asb_rf ///
		past_occurrence urban sh_catholics sh_agr
		
duplicates drop

merge 1:1 cell_id year using `list_match', keepusing(cell_id)
keep if _merge == 3
drop _merge

gen treat = 1
	
append using `non_treated_neighbors'

replace cell_id_n = cell_id if treat == 1

tempfile neighbors_t2
save `neighbors_t2', replace

foreach var in d_sh_jews_credit sh_jews_credit sh_jews sh_credit no_credit ///
	d_sh_jews_trd_gr sh_jews_trd_gr sh_trd_gr latitude longitude urban {
		gen I`var'_mwshock_pt = `var' * mwshock * pol_turmoil
	}

keep cell_id cell_id_n year latitude longitude occurrence ///
	d_sh_jews_trd_gr sh_jews_trd_gr sh_jews sh_trd_gr urban ///
	Id_sh_jews_trd_gr_mwshock_pt Ish_jews_trd_gr_mwshock_pt ///
	Ish_jews_mwshock_pt Ish_trd_gr_mwshock_pt Iurban_mwshock_pt ///
	pol_turmoil mwshock
	
lab var cell_id_n "Neighboring cell identifier"	
lab var year "Year"
	
lab var d_sh_jews_trd_gr "1(Jews among grain traders > median)"
lab var Id_sh_jews_trd_gr_mwshock_pt "Market-wide econ shock x Political turmoil x 1(Jews among grain traders > median)"

lab var sh_jews_trd_gr "Shareo of Jews among grain traders"
lab var Ish_jews_trd_gr_mwshock_pt "Market-wide econ shock x Political turmoil x Share of Jews among grain traders"

lab var sh_jews "Share of Jews"
lab var Ish_jews_mwshock_pt "Market-wide econ shock x Political turmoil x Share of Jews"

lab var sh_trd_gr "Shareo of grain traders"
lab var Ish_trd_gr_mwshock_pt "Market-wide econ shock x Political turmoil x Share of grain traders"

lab var urban "Urbanization rate"
lab var Iurban_mwshock_pt "Market-wide econ shock x Political turmoil x Urbanization rate"

save "$data/data_generated/neighbors_sample_t2_w_duplicates.dta", replace

*************** The version without duplicates but with weights ****************

use `neighbors_t2', clear

preserve 
	gen pweight = 1
	
	collapse (sum) pweight, by(cell_id year)
	
	tempfile weights
	save `weights', replace
restore

drop cell_id_n 
duplicates drop
merge 1:1 cell_id year using `weights'
drop _merge
	
foreach var in d_sh_jews_credit sh_jews_credit sh_jews sh_credit no_credit ///
	d_sh_jews_trd_gr sh_jews_trd_gr sh_trd_gr latitude longitude urban {
		gen I`var'_mwshock_pt = `var' * mwshock * pol_turmoil
	}

keep cell_id year latitude longitude occurrence ///
	Id_sh_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt Ish_jews_mwshock_pt ///
	Ish_trd_gr_mwshock_pt Iurban_mwshock_pt ///
	Ilatitude_mwshock_pt Ilongitude_mwshock_pt ///
	d_sh_jews_trd_gr sh_jews rye_suitability ///
	past_occurrence asb_rf sh_lit_jews sh_lit_non_jews sh_lit_diff ///
	sh_catholic sh_agr urban mwshock pol_turmoil ///
	sh_jews_trd_gr sh_trd_gr pweight sh_credit
	
lab var year "Year"

lab var d_sh_jews_trd_gr "1(Jews among grain traders > median)"
lab var Id_sh_jews_trd_gr_mwshock_pt "Market-wide econ shock x Political turmoil x 1(Jews among grain traders > median)"

lab var sh_jews_trd_gr "1(Jews among grain traders > median)"

lab var sh_jews "Share of Jews"
lab var Ish_jews_mwshock_pt "Market-wide econ shock x Political turmoil x Share of Jews"

lab var sh_trd_gr "Sh. of grain traders"
lab var Ish_trd_gr_mwshock_pt "Market-wide econ shock x Political turmoil x Sh. of grain traders"

lab var urban "Urbanization rate"
lab var Iurban_mwshock_pt "Market-wide econ shock x Political turmoil x Urbanization rate"

lab var latitude "Latitude"
lab var Ilatitude_mwshock_pt "Market-wide econ shock x Political turmoil x Latitude"

lab var longitude "Longitude"
lab var Ilongitude_mwshock_pt "Market-wide econ shock x Political turmoil x Longitude"

lab var sh_trd_gr "Share of grain traders"
lab var Ish_trd_gr_mwshock "Market-wide econ shock x Share of grain traders"		
	
save "$data/data_generated/neighbors_sample_t2_wo_duplicates.dta", replace
