
set more off
clear 
version 14

cd "$figures"
set scheme s1color

*** Figure 2: Pogrom waves, marketwide economic shocks, and political turmoil **

***************************** Panel A: Pogrom waves ****************************

use "$data/pogrom_complete_data_grid", clear

collapse (sum) count occurrence (max) pol_turmoil mwshock, by(year)		
tsset year
	
tab year if count > 0

/*    Year |   Freq.   Percent    Cum.
------------+-----------------------------------
    1821 |     1    5.56    5.56
    1849 |     1    5.56    11.11
    1859 |     1    5.56    16.67
    1871 |     1    5.56    22.22
    1881 |     1    5.56    27.78
    1882 |     1    5.56    33.33
    1883 |     1    5.56    38.89
    1898 |     1    5.56    44.44
    1903 |     1    5.56    50.00
    1904 |     1    5.56    55.56
    1905 |     1    5.56    61.11
    1906 |     1    5.56    66.67
    1917 |     1    5.56    72.22
    1918 |     1    5.56    77.78
    1919 |     1    5.56    83.33
    1920 |     1    5.56    88.89
    1921 |     1    5.56    94.44
    1922 |     1    5.56   100.00
------------+-----------------------------------
   Total |     18   100.00			*/

twoway (line count year) ///
	(tsline count, recast(connected) lcolor(navy) mcolor(navy) yaxis(1) ///
	xlabel(1800 1821 1859 1881 1903 1917 1928) lcolor(black) mcolor(black) msymbol(plus) ///
	ytitle("Number of pogroms", size(medlarge)) xtitle("")), legend(order(2) label(2 "Pogroms"))

graph save figure_2_panel_A_pogrom_occurrence.gph, replace
graph export figure_2_panel_A_pogrom_occurrence.pdf, replace

********************** Panel B: Marketwide economic shocks *********************

tab year if mwshock > 0

/*   Year |   Freq.   Percent    Cum.
------------+-----------------------------------
    1801 |     1    3.33    3.33
    1802 |     1    3.33    6.67
    1818 |     1    3.33    10.00
    1819 |     1    3.33    13.33
    1822 |     1    3.33    16.67
    1823 |     1    3.33    20.00
    1848 |     1    3.33    23.33
    1849 |     1    3.33    26.67
    1872 |     1    3.33    30.00
    1873 |     1    3.33    33.33
    1880 |     1    3.33    36.67
    1881 |     1    3.33    40.00
    1882 |     1    3.33    43.33
    1883 |     1    3.33    46.67
    1890 |     1    3.33    50.00
    1891 |     1    3.33    53.33
    1903 |     1    3.33    56.67
    1904 |     1    3.33    60.00
    1906 |     1    3.33    63.33
    1907 |     1    3.33    66.67
    1910 |     1    3.33    70.00
    1911 |     1    3.33    73.33
    1913 |     1    3.33    76.67
    1914 |     1    3.33    80.00
    1915 |     1    3.33    83.33
    1918 |     1    3.33    86.67
    1919 |     1    3.33    90.00
    1920 |     1    3.33    93.33
    1921 |     1    3.33    96.67
    1922 |     1    3.33   100.00
------------+-----------------------------------
   Total |     30   100.00
*/ 

*** 1801
local start_1 1800.6
local end_1 1802.3

*** 1818
local start_2 1817.6
local end_2 1819.3

*** 1822
local start_3 1821.6
local end_3 1823.3

*** 1848
local start_4 1847.6
local end_4 1849.3

*** 1872
local start_5 1871.6
local end_5 1873.3

*** 1881-1882
local start_6 1879.6
local end_6 1883.3

*** 1890
local start_7 1889.6
local end_7 1891.3

*** 1903
local start_9 1902.6
local end_9 1904.3

*** 1906
local start_10 1905.6
local end_10 1907.3

*** 1910
local start_11 1909.6
local end_11 1912.3

*** 1913-14
local start_12 1912.6
local end_12 1915.3

*** 1918 and 1920-1921
local start_13 1917.6
local end_13 1922.3

twoway (scatteri 200 `start_1' 200 `end_1' , bcolor(eltblue) recast(area)) ///
	(scatteri 200 `start_2' 200 `end_2' , bcolor(eltblue) recast(area) yaxis(1)) ///
	(scatteri 200 `start_3' 200 `end_3' , bcolor(eltblue) recast(area) yaxis(1)) ///
	(scatteri 200 `start_4' 200 `end_4' , bcolor(eltblue) recast(area) yaxis(1)) /// 
	(scatteri 200 `start_5' 200 `end_5' , bcolor(eltblue) recast(area) yaxis(1)) /// 
	(scatteri 200 `start_6' 200 `end_6' , bcolor(eltblue) recast(area) yaxis(1)) ///
	(scatteri 200 `start_7' 200 `end_7' , bcolor(eltblue) recast(area) yaxis(1)) ///
	(scatteri 200 `start_9' 200 `end_9' , bcolor(eltblue) recast(area) yaxis(1)) ///
	(scatteri 200 `start_10' 200 `end_10' , bcolor(eltblue) recast(area) yaxis(1)) /// 
	(scatteri 200 `start_11' 200 `end_11' , bcolor(eltblue) recast(area) yaxis(1)) /// 
	(scatteri 200 `start_12' 200 `end_12' , bcolor(eltblue) recast(area) yaxis(1)) /// 
	(scatteri 200 `start_13' 200 `end_13' , bcolor(eltblue) recast(area) yaxis(1)) /// 
	(tsline count, recast(connected) lcolor(navy) mcolor(navy) yaxis(1) xsc(r(1800 1930)) ///
	xlabel(1800 1821 1859 1881 1903 1917 1928) lcolor(black) mcolor(black) msymbol(plus) ///
	ytitle("Number of pogroms", size(medlarge))) ///
	, legend(order(13 12) label(12 "Crop failure") label(13 "Pogroms"))
graph save figure_2_panel_B_pogrom_occurrence_marketwide_shocks.gph, replace
graph export figure_2_panel_B_pogrom_occurrence_marketwide_shocks.pdf, replace

************************** Panel C: Political turmoil **************************

tab year if pol_turmoil > 0

/*   Year |   Freq.   Percent    Cum.
------------+-----------------------------------
    1803 |     1    3.23    3.23
    1804 |     1    3.23    6.45
    1805 |     1    3.23    9.68
    1806 |     1    3.23    12.90
    1807 |     1    3.23    16.13
    1808 |     1    3.23    19.35
    1812 |     1    3.23    22.58
    1813 |     1    3.23    25.81
    1825 |     1    3.23    29.03
    1826 |     1    3.23    32.26
    1855 |     1    3.23    35.48
    1856 |     1    3.23    38.71
    1857 |     1    3.23    41.94
    1875 |     1    3.23    45.16
    1876 |     1    3.23    48.39
    1877 |     1    3.23    51.61
    1878 |     1    3.23    54.84
    1881 |     1    3.23    58.06
    1882 |     1    3.23    61.29
    1903 |     1    3.23    64.52
    1904 |     1    3.23    67.74
    1905 |     1    3.23    70.97
    1906 |     1    3.23    74.19
    1916 |     1    3.23    77.42
    1917 |     1    3.23    80.65
    1918 |     1    3.23    83.87
    1919 |     1    3.23    87.10
    1920 |     1    3.23    90.32
    1921 |     1    3.23    93.55
    1922 |     1    3.23    96.77
    1923 |     1    3.23   100.00
------------+-----------------------------------
   Total |     31   100.00
*/
	 

*** 1803-1807
local start_21 1802.6
local end_21 1808.3

*** 1812
local start_22 1811.6	
local end_22 1813.3

*** 1825
local start_23 1824.6
local end_23 1826.3

*** 1855-1856
local start_24 1854.6
local end_24 1857.3

*** 1875-1877
local start_25 1874.6
local end_25 1878.3

*** 1881
local start_26 1880.6	
local end_26 1882.3

*** 1903-1906
local start_27 1902.6	
local end_27 1906.3

*** 1915-1923
local start_28 1915.6	
local end_28 1923.3

twoway (scatteri 200 `start_21' 200 `end_21' , bcolor("255 80 80") recast(area)) ///
	(scatteri 200 `start_22' 200 `end_22' , bcolor("255 80 80") recast(area) yaxis(1)) /// 
	(scatteri 200 `start_23' 200 `end_23' , bcolor("255 80 80") recast(area) yaxis(1)) /// 
	(scatteri 200 `start_24' 200 `end_24' , bcolor("255 80 80") recast(area) yaxis(1)) /// 
	(scatteri 200 `start_25' 200 `end_25' , bcolor("255 80 80") recast(area) yaxis(1)) /// 
	(scatteri 200 `start_26' 200 `end_26' , bcolor("255 80 80") recast(area) yaxis(1)) /// 
	(scatteri 200 `start_27' 200 `end_27' , bcolor("255 80 80") recast(area) yaxis(1)) /// 
	(scatteri 200 `start_28' 200 `end_28' , bcolor("255 80 80") recast(area) yaxis(1)) /// 
	(tsline count, recast(connected) lcolor(black) mcolor(black) yaxis(1) xsc(r(1800 1930)) /// 
	xlabel(1800 1821 1859 1881 1903 1917 1928) ///
	text(100 1800.6 "Defeat in the Third and Forth Coalition Wars (1803-1807)", orientation(vertical) color(gs6) size(small)) /// 
	text(100 1809.6 "Napoleon in Moscow (1812)", orientation(vertical) color(gs6) size(small)) ///
	text(100 1819.6 "Constantine Pavlovich abdicates the throne (1825)", orientation(vertical) color(gs6) size(small)) /// 
	text(100 1822.6 "December uprising (1825)", orientation(vertical) color(gs6) size(small)) /// 
	text(100 1852.6 "Defeat in Crimean War (1855-56)", orientation(vertical) color(gs6) size(small)) /// 
	text(100 1872.6 "Russo-Turkish War (1875-1877)", orientation(vertical) color(gs6) size(small)) /// 
	text(100 1883.7 "Assasination of Alexander II (1881)", orientation(vertical) color(gs6) size(small)) /// 
	text(100 1897.6 "General strikes (1903 and 1905), Revolution (1905)", orientation(vertical) color(gs6) size(small)) /// 
	text(100 1900.6 "Defeat in Ruso-Japanese War (1904-05)", orientation(vertical) color(gs6) size(small)) /// 
	text(100 1909.6 "Defeat in WWI (1916-1917)", orientation(vertical) color(gs6) size(small)) ///  
	text(100 1912.6 "2 revolutions (1917), Civil War (1917-22)", orientation(vertical) color(gs6) size(small)) ///  
	msymbol(plus) ytitle("Number of pogroms", size(medlarge))) ///
	, legend(order(9 8) label(8 "Political turmoil") label(9 "Pogroms"))
graph save figure_2_panel_C_pogrom_occurrence_political_turmoil.gph, replace
graph export figure_2_panel_C_pogrom_occurrence_political_turmoil.pdf, replace

******** Panel D: Pogroms and the intersection of marketwide econ shock ********
***************************** and political turmoil ****************************

tab year if mwshock > 0 & pol_turmoil > 0

/*   Year |   Freq.   Percent    Cum.
------------+-----------------------------------
    1881 |     1    10.00    10.00
    1882 |     1    10.00    20.00
    1903 |     1    10.00    30.00
    1904 |     1    10.00    40.00
    1906 |     1    10.00    50.00
    1918 |     1    10.00    60.00
    1919 |     1    10.00    70.00
    1920 |     1    10.00    80.00
    1921 |     1    10.00    90.00
    1922 |     1    10.00   100.00
------------+-----------------------------------
   Total |     10   100.00			*/	 

local start_31 1880.6	
local end_31 1882.3

local start_32 1902.6	
local end_32 1904.3

local start_34 1905.6
local end_34 1906.3

local start_33 1917.6	
local end_33 1922.3

twoway (scatteri 200 `start_31' 200 `end_31' , bcolor("155 30 155") recast(area)) ///
	(scatteri 200 `start_32' 200 `end_32' , bcolor("155 30 155") recast(area) yaxis(1)) ///
	(scatteri 200 `start_33' 200 `end_33' , bcolor("155 30 155") recast(area) yaxis(1)) /// 
	(scatteri 200 `start_34' 200 `end_34' , bcolor("155 30 155") recast(area) yaxis(1)) /// 
	(tsline count, recast(connected) lcolor(black) mcolor(black) yaxis(1) xsc(r(1800 1930)) /// 
	xlabel(1800 1821 1859 1881 1903 1917 1928) /// 
	msymbol(plus) ytitle("Number of pogroms", size(medlarge))) ///
	, legend(order(5 4) label(4 "Political turmoil and crop failure") label(5 "Pogroms"))
graph save figure_2_panel_D_pogrom_occurrence_marketwide_shocks_political_turmoil.gph, replace
graph export figure_2_panel_D_pogrom_occurrence_marketwide_shocks_political_turmoil.pdf, replace
