
set more off
clear 
version 14

cd "$figures"
set scheme s1color

********* Figure 4: Pogroms, spring temperature, and political turmoil *********

	use "$data/pogrom_complete_data_grid", clear
				
	keep sdev_temp_sp_rm75 count occurrence cell_id year pol_turmoil

	** Values for the vertical lines
	
	_pctile sdev_temp_sp_rm75, nq(100)		

	local temp_sp_p5 = r(r5)
	local temp_sp_p10 = r(r10)
	local temp_sp_p90 = r(r90)
	local temp_sp_p95 = r(r95)
	
	** Lowess: All years **
	
	lowess occurrence sdev_temp_sp_rm75, ///
		bw(0.7) gen(y_sdev_temp_sp_rm75) nograph adjust

	** Lowess: Years with political turmoil **
	
	preserve
		keep if pol_turmoil == 1
		
		lowess occurrence sdev_temp_sp_rm75, ///
			bw(0.7) gen(y_sdev_temp_sp_rm75_pt) nograph adjust
		
		keep y_sdev_temp_sp_rm75_pt cell_id year
		
		tempfile pol_turmoil
		save `pol_turmoil', replace
	restore

	** Merging lowess lines from all years with those from years with political turmoil
	
	merge 1:1 cell_id year using `pol_turmoil'
	drop _merge
	
	** Labelling vars for output
	
	lab var sdev_temp_sp_rm75 "Spring temperature: deviation from the historical mean"
	lab var y_sdev_temp_sp_rm75 "Dummy: occurrence of pogrom"
	lab var y_sdev_temp_sp_rm75_pt "Dummy: occurrence of pogrom"

	** Plotting the lowess lines

	twoway	(line y_sdev_temp_sp_rm75 sdev_temp_sp_rm75, sort lcolor(maroon)) ///
		    (line y_sdev_temp_sp_rm75_pt sdev_temp_sp_rm75 if pol_turmoil == 1, sort lcolor(dknavy) lpattern(longdash)), ///
		ylabel(0[0.01]0.06) xlabel(-4[2]4) ///
		xline(`temp_sp_p5', lpattern(dash)) xline(`temp_sp_p10') ///
		xline(`temp_sp_p90') xline(`temp_sp_p95', lpattern(dash)) ///
		legend(col(2) label(1 "All years") label(2 "Political turmoil"))
	graph save figure_4_occurrence_spring_temperature, replace
	graph export figure_4_occurrence_spring_temperature.pdf, replace
