
set more off
clear all 
version 14

cd "$figures"
set scheme s1color

********************************** Figure A10 **********************************

use "$data/grain_price_harvest_complete_data_gubernia.dta", clear

********** Panel A: Grain harvest by suitability for grain cultivation *********

collapse (sum) grain_harvest (mean) grain_price mwshock, by(year suitable_grain)
	
reshape wide grain_harvest@ grain_price@ mwshock@, i(year) j(suitable_grain) 

twoway 	(connected grain_harvest1 year, ///
			lcolor(navy) lpattern(longdash) mcolor(dknavy) msymbol(plus)) ///
		(connected grain_harvest0 year, ///
			lcolor(maroon) mcolor(maroon) msymbol(circle_hollow)) ///
	if grain_harvest1 != 0 & year >= 1860 & year <= 1915, ///
	xlabel(1860 1872 1881 1890 1903 1906 1910 1913 1915, angle(60)) ///
	ytitle("Grain harvest (1000s)", size(medlarge)) xtitle("Year") ///
	legend(label(1 "Harvest, more suitable provinces") ///
		label(2 "Harvest, less suitable provinces") si(small)) 
graph save figure_a10_panel_A_grain_harvest_suitability.gph, replace
graph export figure_a10_panel_A_grain_harvest_suitability.pdf, replace	

******** Panel B: Grain price and agroclimatic shocks in suitably areas ********

*** 1872
local start_5 1871.6
local end_5 1873.3

*** 1881-1882
local start_6 1879.6
local end_6 1883.3

*** 1890
local start_7 1889.6
local end_7 1891.3

*** 1903
local start_9 1902.6
local end_9 1904.3

*** 1906
local start_10 1905.6
local end_10 1907.3

*** 1910
local start_11 1909.6
local end_11 1912.3

*** 1913-14
local start_12 1912.6
local end_12 1915.3

twoway	(scatteri 80 `start_5' 80 `end_5' , bcolor(gs11) recast(area) yaxis(1)) ///
		(scatteri 80 `start_6' 80 `end_6' , bcolor(gs11) recast(area) yaxis(1)) ///
		(scatteri 80 `start_7' 80 `end_7' , bcolor(gs11) recast(area) yaxis(1)) ///
		(scatteri 80 `start_9' 80 `end_9' , bcolor(gs11) recast(area) yaxis(1)) ///
		(scatteri 80 `start_10' 80 `end_10' , bcolor(gs11) recast(area) yaxis(1)) ///
		(scatteri 80 `start_11' 80 `end_11' , bcolor(gs11) recast(area) yaxis(1)) ///
		(scatteri 80 `start_12' 80 `end_12' , bcolor(gs11) recast(area) yaxis(1)) ///
		(line grain_price1 year, recast(connected) lcolor(navy) lpattern(longdash) mcolor(navy) ///
			color(black) mcolor(black) msymbol(plus) yaxis(1)) ///
		(line grain_price0 year, recast(connected) lcolor("139 69 19") mcolor("139 69 19") ///
		color("maroon") mcolor("maroon") msymbol(circle_hollow) yaxis(1)) ///
	if year >= 1860 & year <= 1915, ///
	xsc(r(1860 1915)) ///
	xlabel(1860 1872 1881 1890 1903 1906 1910 1913 1915, angle(60)) ///
	ytitle("Price of rye", size(medlarge)) ///
	legend(row(1) order(8 9 7) ///
		label(8 "Price, more suitable") ///
		label(9 "Price, less suitable") ///
		label(7 "Marketwide econ shocks") si(vsmall)) 
graph save figure_a10_panel_B_grain_price_suitability_macro_shocks_suitable.gph, replace
graph export figure_a10_panel_B_grain_price_suitability_macro_shocks_suitable.pdf, replace
	
