
set more off
clear all 
version 14	

cd "$figures"
set scheme s1color

******************** Figure A12: Russia's bond yield spread ********************

use "$data/figure_a12_bond_spread_monthly.dta", clear

gen quarter = .
replace quarter = 1 if month == 1 | month == 2 | month == 3
replace quarter = 2 if month == 4 | month == 5 | month == 6
replace quarter = 3 if month == 7 | month == 8 | month == 9
replace quarter = 4 if month == 10 | month == 11 | month == 12

collapse (mean) bond_spread, by(year quarter)

gen date_quarter = string(year) + " Q" + string(quarter)
gen qdate = quarterly(date_quarter, "YQ")
gen qdate2 = qdate
format qdate %tq

sort date

gen bond_spread_p3m = bond_spread[_n-1]
gen bond_spread_dt_p3m = (bond_spread - bond_spread_p3m) 

*** 1874-75
local start_21 -338.3	
local end_21 -329.6

*** 1881
local start_22 -315.3 
local end_22 -308.6 

*** 1903-1906
local start_23 -227.3 
local end_23 -212.6 

twoway  (scatteri 0.04 `start_21' 0.04 `end_21' , bcolor(gs8) recast(area), yaxis(2)) ///
		(scatteri 0.04 `start_22' 0.04 `end_22' , bcolor(gs8) recast(area), yaxis(2)) ///	
		(scatteri 0.04 `start_23' 0.04 `end_23' , bcolor(gs8) recast(area), yaxis(2)) ///
		(line bond_spread qdate, lcolor(dknavy) lwidth(medthick) yaxis(1)) ///
		(line bond_spread_dt_p3m qdate, lcolor(maroon) lwidth(thin) lpattern(shortdash) yaxis(2)), ///
		yline(0, axis(2)) xtitle(Date) xlabel(-360[16]-180, angle(60)) ///
		ytitle("First difference in yield spread", axis(2)) ///
		ytitle("Yield spread, quarterly average") ///
		legend(order(4 5 1) row(1) label(1 "Political turmoil") ///
		label(5 "First diff. in yield spread") label(4 "Yield spread") si(small))
graph save figure_a12_bond_spread_3month_average_first_difference.gph, replace
graph export figure_a12_bond_spread_3month_average_first_difference.pdf, replace
