
set more off
clear 
version 14	

cd "$figures"
set scheme s1color

******* Figure A8: Lowess grain harvest by season at the gubernia level *******
	
use "$data/pogrom_complete_data_grid.dta", clear

keep if year <= 1927
	
_pctile sdev_temp_sp_rm75, nq(100)		

local temp_sp_p5 = r(r5)
local temp_sp_p10 = r(r10)
local temp_sp_p90 = r(r90)
local temp_sp_p95 = r(r95)

_pctile sdev_temp_su_rm75, nq(100)		

local temp_su_p5 = r(r5)
local temp_su_p10 = r(r10)
local temp_su_p90 = r(r90)
local temp_su_p95 = r(r95)

_pctile sdev_temp_wi_rm75, nq(100)		

local temp_wi_p5 = r(r5)
local temp_wi_p10 = r(r10)
local temp_wi_p90 = r(r90)
local temp_wi_p95 = r(r95)

_pctile sdev_temp_au_rm75, nq(100)		

local temp_au_p5 = r(r5)
local temp_au_p10 = r(r10)
local temp_au_p90 = r(r90)
local temp_au_p95 = r(r95)

*** Lowess graphs ***

use "$data/grain_price_harvest_complete_data_gubernia.dta", clear

xi i.gub_id, noomit
rename _Igub_id* gub_id*
xi i.year, noomit
rename _Iyear* year*

** Partialling out province and year effects **

global controls gub_id* year*

foreach season in temp_sp temp_su temp_au temp_wi {
	semipar grain_harvest ${controls}, nonpar(sdev_`season'_rm75) ///
		gen(y_sdev_`season'_rm75) 	 
	lab var y_sdev_`season'_rm75 "Yield (1000s)"
	
	if "`season'" == "temp_sp" {
		local panel = "A"
		}
		
	if "`season'" == "temp_su" {
		local panel = "B"
		}
		
	if "`season'" == "temp_au" {
		local panel = "C"
		}
		
	if "`season'" == "temp_wi" {
		local panel = "D"
		}
	
	if "`season'" == "temp_sp" {
		_pctile sdev_`season'_rm75, nq(1000)		
		twoway line y_sdev_`season'_rm75 sdev_`season'_rm75 ///
			if sdev_`season'_rm75 > `r(r5)' ///
			& sdev_`season'_rm75 < `r(r995)', sort lcolor(dknavy) ///
		ylabel(-9000[3000]6000) ///
		xline(``season'_p5', lpattern(dash)) xline(``season'_p10') xline(``season'_p90') xline(``season'_p95', lpattern(dash))
		}	
		
	else{
		_pctile sdev_`season'_rm75, nq(1000)		
		twoway line y_sdev_`season'_rm75 sdev_`season'_rm75 ///
			if sdev_`season'_rm75 > `r(r5)' ///
			& sdev_`season'_rm75 < `r(r995)', sort lcolor(dknavy) ///
		ylabel(-3000[3000]12000) ///
		xline(``season'_p5', lpattern(dash)) xline(``season'_p10') xline(``season'_p90') xline(``season'_p95', lpattern(dash))
		}
		
	graph export figure_a8_panel_`panel'_grain_harvest_`season'_1pcts_2fe.pdf, as(pdf) replace

	drop y_sdev_`season'_rm75
}
