
set more off
clear 
version 14	

cd "$tables"

** Table 10: Alternative measures of political turmoil and marketwide economic shocks **

use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id	

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

global hetero_jews_credit_bsy ///
	Ish_jews_credit_lshock_bsy Ish_jews_credit_lshock Ish_jews_credit_bsy ///
	Ish_jews_lshock_bsy Ish_jews_lshock Ish_jews_bsy ///
	Ino_credit_lshock_bsy Ino_credit_lshock Ino_credit_bsy ///
	Icapital_lshock_bsy Icapital_lshock Icapital_bsy ///
	Id_bspready_lshock lshock 

global hetero_jews_credit_pt ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil /// 
	Icapital_lshock_pt Icapital_lshock Icapital_pol_turmoil /// 
	Ipol_turmoil_lshock lshock pol_turmoil 

global hetero_jews_trd_gr_bsy_pars ///
	Ish_jews_trd_gr_mwshock_bsy ///
	Ish_jews_mwshock_bsy ///
	Icapital_mwshock_bsy

global hetero_jews_trd_gr_pt_pars ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_jews_mwshock_pt ///
	Icapital_mwshock_pt

global pshock_jews_trd_gr ///
	Ilog_jews_trd_gr_lgprice_pt Ilog_jews_trd_gr_lgprice Ilog_jews_trd_gr_pol_turmoil  ///
	Ilog_tot_pop_lgprice_pt Ilog_tot_pop_lgprice Ilog_tot_pop_pol_turmoil ///
	Ish_jews_lgprice_pt Ish_jews_lgprice Ish_jews_pol_turmoil ///
	Icapital_lgprice_pt Icapital_lgprice Icapital_pol_turmoil ///
	lgprice Ilgprice_pol_turmoil
			
global mshock_jews_trd_gr ///
	Ilog_jews_trd_gr_mwshock_pt ///
	Ilog_tot_pop_mwshock_pt ///
	Ish_jews_mwshock_pt ///
	Icapital_mwshock_pt 
	
global bspread_sample if d_bspready != . 
global price_sample if gprice != .

replace occurrence = occurrence * 100

**

keep cell_id year latitude longitude occurrence d_bspready ///
	$hetero_jews_credit_pt $hetero_jews_trd_gr_pt_pars ///
	$hetero_jews_credit_bsy $hetero_jews_trd_gr_bsy_pars ///
	$pshock_jews_trd_gr $mshock_jews_trd_gr gprice 
	
***************** Panel A: Rising spread as political turmoil; *****************
******************* grain price as marketwide economic shock *******************

global vars_report Ish_jews_credit_lshock_bsy ///
	Ish_jews_trd_gr_mwshock_bsy ///
	Ilog_jews_trd_gr_lgprice_pt 
	
	** 1
	
	reg occurrence ${hetero_jews_credit_bsy} ///
		${year_FE} ${cell_FE} ${bspread_sample}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_credit_bsy} ${bspread_sample}, ${acreg_option}
	outreg2 using table_10_panel_A_occurrence_results_heterogenous_robustness_bond_spread_lgprice.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace			
	
	** 2
		
	reg occurrence ${hetero_jews_trd_gr_bsy_pars} ///
		${year_FE} ${cell_FE} ${bspread_sample}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_trd_gr_bsy_pars} ${bspread_sample}, ${acreg_option}
	outreg2 using table_10_panel_A_occurrence_results_heterogenous_robustness_bond_spread_lgprice.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			
	
	** 3
	
	reg occurrence ${pshock_jews_trd_gr} ///
		i.year i.cell_id ${price_sample}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${pshock_jews_trd_gr} ${price_sample}, ${acreg_option}
	outreg2 using table_10_panel_A_occurrence_results_heterogenous_robustness_bond_spread_lgprice.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			
			
************* Panel B: Baseline specification on the same samples **************

global vars_report Ish_jews_credit_lshock_pt ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ilog_jews_trd_gr_mwshock_pt 
	
	** 1
	
	reg occurrence ${hetero_jews_credit_pt} ///
		${year_FE} ${cell_FE} ${bspread_sample}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_credit_pt} ${bspread_sample}, ${acreg_option}
	outreg2 using table_10_panel_B_occurrence_results_heterogenous_robustness_bond_spread_lgprice.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace			
	
	** 2
		
	reg occurrence ${hetero_jews_trd_gr_pt_pars} ///
		${year_FE} ${cell_FE} ${bspread_sample}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_trd_gr_pt_pars} ${bspread_sample}, ${acreg_option}
	outreg2 using table_10_panel_B_occurrence_results_heterogenous_robustness_bond_spread_lgprice.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("Wave 3") ${add_stat} nonotes nocon nor2 label append			

	** 3
		
	reg occurrence ${mshock_jews_trd_gr} ///
		i.year i.cell_id ${price_sample}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${mshock_jews_trd_gr} ${price_sample}, ${acreg_option}
	outreg2 using table_10_panel_B_occurrence_results_heterogenous_robustness_bond_spread_lgprice.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("All waves") ${add_stat} nonotes nocon nor2 label append			
