
set more off
clear 
version 14	

cd "$tables"

****************** Table 11: Enforcement capacity of the state *****************

use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

rename *sh_jews_credit* *sh_jews_crdt*
rename *sh_jews_trd_gr* *sh_jews_tgr*
	
***************** Panel A: The effects of local economic shocks ****************

global hetero_jews_credit_dummy ///
	Ish_jews_crdt_lshock Ish_jews_lshock ///
	Ino_credit_lshock lshock 

global hetero_jews_credit_dummy_p1917 ///
	Ish_jews_crdt_lshock_p1917 Ish_jews_lshock_p1917 ///
	Ino_credit_lshock_p1917 Ilshock_p1917 
	
global hetero_grain_trd_dummy ///
	Ish_jews_tgr_mwshock_pt Ish_jews_mwshock_pt

global hetero_grain_trd_dummy_p1917 ///
	Ish_jews_tgr_mwshock_p1917_pt Ish_jews_mwshock_p1917_pt

**
	
global acreg_option_credit id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global acreg_option_credit_ext id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id_1917) pfe2(year)

global acreg_option_grain_trade id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(year)
	
keep cell_id cell_id_1917 year latitude longitude occurrence ///
	wave8182 wave0306 wave1722 ///
	${hetero_jews_credit_dummy} ${hetero_jews_credit_dummy_p1917} ///
	${hetero_grain_trd_dummy} ${hetero_grain_trd_dummy_p1917}
	
replace occurrence = occurrence * 100	
	
global vars_report Ish_jews_crdt_lshock Ish_jews_crdt_lshock_p1917 ///
	Ish_jews_lshock Ish_jews_lshock_p1917 

	** 1: Before 1917 
	
	reg occurrence ${hetero_jews_credit_dummy} ${year_FE} ${cell_FE} if wave8182 | wave0306
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)	

	acreg occurrence ${hetero_jews_credit_dummy} if wave8182 | wave0306, ${acreg_option_credit}
	outreg2 using table_11_panel_A_occurrence_results_heterogenous_local_shocks_state_capacity.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		${add_stat} ctitle("Waves 1 & 2") nonotes nocon nor2 label replace

	** 2: After 1917 
	
	reg occurrence ${hetero_jews_credit_dummy} ${year_FE} ${cell_FE} if wave1722
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)	
	
	acreg occurrence ${hetero_jews_credit_dummy} if wave1722, ${acreg_option_credit}
	outreg2 using table_11_panel_A_occurrence_results_heterogenous_local_shocks_state_capacity.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		${add_stat} ctitle("Wave 3") nonotes nocon nor2 label append
		
	** 3: Three waves with interactions
	
	reg occurrence ${hetero_jews_credit_dummy} ${hetero_jews_credit_dummy_p1917} ///
		${year_FE} ${cell_FE} if wave8182 | wave0306 | wave1722
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)	

	acreg occurrence ${hetero_jews_credit_dummy} ${hetero_jews_credit_dummy_p1917} ///
		if wave8182 | wave0306 | wave1722, ${acreg_option_credit_ext}
	outreg2 using table_11_panel_A_occurrence_results_heterogenous_local_shocks_state_capacity.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		${add_stat} ctitle("All waves") nonotes nocon nor2 label append
		
*************** Panel A: The effects of marketwide economic shocks *************

global vars_report Ish_jews_tgr_mwshock_pt Ish_jews_tgr_mwshock_p1917_pt ///
	Ish_jews_mwshock_pt Ish_jews_mwshock_p1917_pt
	
	** 4: Before 1917 
	
	reg occurrence ${hetero_grain_trd_dummy} ${year_FE} if wave8182 | wave0306
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)	

	acreg occurrence ${hetero_grain_trd_dummy} if wave8182 | wave0306, ${acreg_option_grain_trade}
	outreg2 using table_11_panel_B_occurrence_results_heterogenous_marketwide_shocks_state_capacity.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		${add_stat} ctitle("Waves 1 & 2") nonotes nocon nor2 label replace
		
	** 5: After 1917 
	
	reg occurrence ${hetero_grain_trd_dummy} ${year_FE} if wave1722
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)	

	acreg occurrence ${hetero_grain_trd_dummy} if wave1722, ${acreg_option_grain_trade}
	outreg2 using table_11_panel_B_occurrence_results_heterogenous_marketwide_shocks_state_capacity.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		${add_stat} ctitle("Wave 3") nonotes nocon nor2 label append

	** 6: Three waves with interactions
	
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_grain_trd_dummy_p1917} ///
		${year_FE} if wave8182 | wave0306 | wave1722
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)	

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_grain_trd_dummy_p1917} ///
		if wave1722 | wave8182 | wave0306, ${acreg_option_grain_trade}
	outreg2 using table_11_panel_B_occurrence_results_heterogenous_marketwide_shocks_state_capacity.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		${add_stat} ctitle("All waves") nonotes nocon nor2 label append
