
set more off
clear 
version 14	

cd "$tables"

****************** Table 12: Placebo: general crime, 1900–1912 *****************

use "$data/pogrom_complete_data_grid.dta", clear

global year_FE i.year
global cell_FE i.cell_id
	
global add_stat adds(Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

global hetero_jews_credit_dummy ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil /// 		
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil ///
	lshock Ipol_turmoil_lshock

global hetero_jews_trd_gr_dummy ///
	Ish_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt   

replace occurrence = occurrence * 100
replace theft_pc = theft_pc * 100
replace homicide_pc = homicide_pc * 100
replace arson_pc = arson_pc * 100

keep cell_id year occurrence theft_pc homicide_pc arson_pc ///
	${hetero_jews_credit_dummy} ${hetero_jews_trd_gr_dummy}

keep if year >= 1900 & year <= 1912

***************** Panel A: The effects of local economic shock *****************
	
global vars_report Ish_jews_credit_lshock_pt Ish_jews_lshock_pt

	** 1

	xi: reg occurrence ${hetero_jews_credit_dummy} ${year_FE} ${cell_FE}, cluster(cell_id)

	sum occurrence if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_12_panel_A_placebo_crime_local_shocks.xls, ///
		ctitle("occurrence") tex(frag) excel bdec(2) tdec(2) sdec(2) ///
		keep(${vars_report}) sortvar(${vars_report}) ${add_stat} nonotes nocon label replace

	** 2

	xi: reg theft_pc ${hetero_jews_credit_dummy} ${year_FE} ${cell_FE}, cluster(cell_id)

	sum theft_pc if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_12_panel_A_placebo_crime_local_shocks.xls, ///
		ctitle("theft pc") tex(frag) excel bdec(2) tdec(2) sdec(2) ///
		keep(${vars_report}) sortvar(${vars_report}) ${add_stat} nonotes nocon label append

	** 3

	xi: reg homicide_pc ${hetero_jews_credit_dummy} ${year_FE} ${cell_FE}, cluster(cell_id)

	sum homicide_pc if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_12_panel_A_placebo_crime_local_shocks.xls, ///
		ctitle("homicide pc") tex(frag) excel bdec(2) tdec(2) sdec(2) ///
		keep(${vars_report}) sortvar(${vars_report}) ${add_stat} nonotes nocon label append

	** 4

	xi: reg arson_pc ${hetero_jews_credit_dummy} ${year_FE} ${cell_FE}, cluster(cell_id)

	sum arson_pc if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_12_panel_A_placebo_crime_local_shocks.xls, ///
		ctitle("arson pc") tex(frag) excel bdec(2) tdec(2) sdec(2) ///
		keep(${vars_report}) sortvar(${vars_report}) ${add_stat} nonotes nocon label append

*************** Panel A: The effects of markewide economic shock ***************

global vars_report Ish_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt

	** 1

	xi: reg occurrence ${hetero_jews_trd_gr_dummy} ${year_FE} ${cell_FE}, cluster(cell_id)

	sum occurrence if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_12_panel_B_placebo_crime_marketwide_shocks.xls, ///
		ctitle("occurrence") tex(frag) excel bdec(2) tdec(2) sdec(2) ///
		keep(${vars_report}) sortvar(${vars_report}) ${add_stat} nonotes nocon label replace

	** 2

	xi: reg theft_pc ${hetero_jews_trd_gr_dummy} ${year_FE} ${cell_FE}, cluster(cell_id)

	sum theft_pc if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_12_panel_B_placebo_crime_marketwide_shocks.xls, ///
		ctitle("theft pc") tex(frag) excel bdec(2) tdec(2) sdec(2) ///
		keep(${vars_report}) sortvar(${vars_report}) ${add_stat} nonotes nocon label append

	** 3

	xi: reg homicide_pc ${hetero_jews_trd_gr_dummy} ${year_FE} ${cell_FE}, cluster(cell_id)

	sum homicide_pc if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_12_panel_B_placebo_crime_marketwide_shocks.xls, ///
		ctitle("homicide pc") tex(frag) excel bdec(2) tdec(2) sdec(2) ///
		keep(${vars_report}) sortvar(${vars_report}) ${add_stat} nonotes nocon label append

	** 4

	xi: reg arson_pc ${hetero_jews_trd_gr_dummy} ${year_FE} ${cell_FE}, cluster(cell_id)

	sum arson_pc if e(sample) 
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_12_panel_B_placebo_crime_marketwide_shocks.xls, ///
		ctitle("arson pc") tex(frag) excel bdec(2) tdec(2) sdec(2) ///
		keep(${vars_report}) sortvar(${vars_report}) ${add_stat} nonotes nocon label append
		
