
set more off
clear 
version 14

cd "$tables"

** Table 2: Grain yield, grain price, and the local and marketwide econ shocks **

use "$data/grain_price_harvest_complete_data_gubernia.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global gubernia_FE i.gub_id

global acreg_option id(gub_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_gub} ///
	pfe1(gub_id) pfe2(year)
global acreg_option_wo_gub_FE id(gub_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_gub} pfe1(year) 
global acreg_option_wo_FE id(gub_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_gub} 
		
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)
	
keep gub_id year latitude longitude ///
	log_grain_harvest log_grain_price ///
	lshock lshock_lag1 Ipol_turmoil_lshock ///
	Isg_lshock Isg_lshock_lag1 ///
	mwshock pol_turmoil Ipol_turmoil_mwshock ///
	suitable_grain log_grain_price_lag1

global vars_report lshock lshock_lag1 Ipol_turmoil_lshock ///
	Isg_lshock Isg_lshock_lag1 ///
	mwshock pol_turmoil Ipol_turmoil_mwshock ///
	suitable_grain log_grain_price_lag1
				
	** 1
	
	reg log_grain_harvest lshock ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_harvest lshock if year >= 1864, ${acreg_option}
	outreg2 using table_2_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 replace
				
	** 2
	
	reg log_grain_harvest lshock lshock_lag1 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_harvest lshock lshock_lag1 if year >= 1864, ${acreg_option}
	outreg2 using table_2_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append
	
	** 3
	
	reg log_grain_harvest lshock Ipol_turmoil_lshock ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_harvest lshock Ipol_turmoil_lshock, ${acreg_option}
	outreg2 using table_2_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append
					
	** 4
	
	reg log_grain_price lshock lshock_lag1 log_grain_price_lag1 ${year_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price lshock lshock_lag1 log_grain_price_lag1, ${acreg_option_wo_gub_FE}
	outreg2 using table_2_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append

	** 5
	
	reg log_grain_price lshock Isg_lshock lshock_lag1 Isg_lshock_lag1 ///
		log_grain_price_lag1 suitable_grain ${year_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price lshock Isg_lshock ///
		lshock_lag1 Isg_lshock_lag1 log_grain_price_lag1 ///
		suitable_grain, ${acreg_option_wo_gub_FE}
	outreg2 using table_2_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append
	
	** 6
	
	reg log_grain_price mwshock, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price mwshock, ${acreg_option_wo_FE}
	outreg2 using table_2_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append
	
	** 7
	
	reg log_grain_price mwshock pol_turmoil, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price mwshock pol_turmoil, ${acreg_option_wo_FE}
	outreg2 using table_2_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append
	
	** 8
	
	reg log_grain_price mwshock pol_turmoil Ipol_turmoil_mwshock, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price mwshock pol_turmoil Ipol_turmoil_mwshock, ${acreg_option_wo_FE}
	outreg2 using table_2_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append		
