
set more off
clear 
version 14

cd "$tables"
		
****** Table 3: Pogrom occurrence, economic shocks, and political turmoil ******

use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id
	
global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
global acreg_option_wo_YFE id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id)

global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

keep cell_id occurrence latitude longitude year ///
	lshock mwshock pol_turmoil Ipol_turmoil_lshock Ipol_turmoil_mwshock ///
	Ish_jews_lshock_pt Ish_jews_pol_turmoil Ish_jews_lshock  ///
	Ish_jews_mwshock_pt Ish_jews_mwshock
	
global vars_report lshock mwshock pol_turmoil ///
	Ipol_turmoil_lshock Ipol_turmoil_mwshock ///
	Ish_jews_lshock_pt Ish_jews_pol_turmoil Ish_jews_lshock  ///
	Ish_jews_mwshock_pt Ish_jews_mwshock
	
replace occurrence = occurrence * 100	
	
	** 1
	
	xi: reg occurrence lshock ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)
	
	acreg occurrence lshock, ${acreg_option_wo_YFE}
	outreg2 using table_3_occurrence_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label replace	
	
	** 2
	
	xi: reg occurrence mwshock ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)
	
	acreg occurrence mwshock, ${acreg_option_wo_YFE}
	outreg2 using table_3_occurrence_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append

	** 3
	
	xi: reg occurrence lshock Ipol_turmoil_lshock pol_turmoil ///
		${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)

	acreg occurrence lshock pol_turmoil Ipol_turmoil_lshock, ${acreg_option_wo_YFE}
	outreg2 using table_3_occurrence_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append
	
	** 4

	xi: reg occurrence mwshock Ipol_turmoil_mwshock pol_turmoil ///
		${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)
	
	acreg occurrence mwshock Ipol_turmoil_mwshock pol_turmoil, ${acreg_option_wo_YFE}
	outreg2 using table_3_occurrence_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append

	** 5
	
	xi: reg occurrence lshock ${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)
	
	acreg occurrence lshock, ${acreg_option}
	outreg2 using table_3_occurrence_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append
		
	** 6
	
	xi: reg occurrence lshock Ipol_turmoil_lshock ${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)

	acreg occurrence lshock Ipol_turmoil_lshock, ${acreg_option}
	outreg2 using table_3_occurrence_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append
		
	** 7
	
	xi: reg occurrence lshock Ipol_turmoil_lshock ///
		Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil ///
		Ish_jews_mwshock_pt Ish_jews_mwshock ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)

	acreg occurrence lshock Ipol_turmoil_lshock ///
		Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil ///
		Ish_jews_mwshock_pt Ish_jews_mwshock, ${acreg_option}
	outreg2 using table_3_occurrence_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append		
