
set more off
clear 
version 14	

cd "$tables"

******** Table 4: Pogroms and Jewish domination in middleman occupations ******* 

use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

global hetero_shock lshock Ipol_turmoil_lshock 

global hetero_jews ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  
	
global hetero_jews_trd_gr ///
	Ish_trd_gr_lshock_pt Ish_trd_gr_lshock Ish_trd_gr_pol_turmoil ///
	Ish_jews_trd_gr_lshock_pt Ish_jews_trd_gr_lshock Ish_jews_trd_gr_pol_turmoil 
	
global hetero_jews_mrktwide ///
	Ish_jews_mwshock_pt Ish_jews_mwshock Ish_jews_pol_turmoil  

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt Ish_jews_trd_gr_mwshock Ish_jews_trd_gr_pol_turmoil  ///
	Ish_trd_gr_mwshock_pt Ish_trd_gr_mwshock Ish_trd_gr_pol_turmoil  
	
keep cell_id year latitude longitude occurrence ///
	${hetero_shock} ${hetero_jews} ///
	${hetero_jews_trd_gr} ${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide}
	
global vars_report Ish_jews_credit_lshock_pt Ish_jews_trd_gr_lshock_pt Ish_jews_trd_gr_mwshock_pt ///
	 Ish_jews_credit_pol_turmoil Ish_jews_credit_lshock ///
	 Ish_jews_trd_gr_pol_turmoil Ish_jews_trd_gr_lshock ///
	 Ish_jews_trd_gr_mwshock Ipol_turmoil_lshock Ish_jews_lshock_pt

replace occurrence = occurrence * 100
	
	** 1

	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ${hetero_jews_credit}, ${acreg_option}
	outreg2 using table_4_occurrence_heterogenous_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label replace			

	** 2

	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_trd_gr} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews}	${hetero_jews_trd_gr}, ${acreg_option}
	outreg2 using table_4_occurrence_heterogenous_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append			

	** 3

	reg occurrence ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_4_occurrence_heterogenous_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append			

	** 4
			
	global hetero_jews_mrktwide Ish_jews_mwshock_pt  
	global hetero_jews_trd_gr_mrktwide ///
		Ish_jews_trd_gr_mwshock_pt Ish_trd_gr_mwshock_pt 

	reg occurrence ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_4_occurrence_heterogenous_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append			

	** 5
	
	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_4_occurrence_heterogenous_results_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append			
		
