
set more off
clear 
version 14	

cd "$tables"

****** Table 5: The share of Jews in major occupations, economic shocks, *******
***************************** and political turmoil ****************************

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome, ///
	Mean of var of interest, mean_var, s.d. of var of interest, sd_var)

***************** Panel A: The effects of local economic shocks ****************

use "$data/pogrom_complete_data_grid.dta", clear

global hetero_jews lshock Ipol_turmoil_lshock ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  
	
global hetero_jews_trd_gr ///
	Ish_jews_trd_gr_lshock_pt Ish_jews_trd_gr_lshock Ish_jews_trd_gr_pol_turmoil
	
global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil 
	
global hetero_nagr_trd ///
	Ish_jews_nagr_trd_lshock_pt Ish_jews_nagr_trd_lshock Ish_jews_nagr_trd_pol_turmoil
	 
global hetero_general_trd ///
	Ish_jews_trd_gnrl_lshock_pt Ish_jews_trd_gnrl_lshock Ish_jews_trd_gnrl_pol_turmoil

global hetero_industry ///
	Ish_jews_crafts_lshock_pt Ish_jews_crafts_lshock Ish_jews_crafts_pol_turmoil
	
global hetero_transport ///
	Ish_jews_trns_lshock_pt Ish_jews_trns_lshock Ish_jews_trns_pol_turmoil 
	
global hetero_agr ///
	Ish_jews_agr_lshock_pt Ish_jews_agr_lshock Ish_jews_agr_pol_turmoil

keep cell_id year latitude longitude occurrence ///
	${hetero_jews} ${hetero_jews_trd_gr} ///
	${hetero_jews_credit} ${hetero_agr} ///
	${hetero_nagr_trd} ${hetero_general_trd} ///
	${hetero_industry} ${hetero_transport} ///
	sh_jews_trd_gr sh_jews_credit sh_jews_agr ///
	sh_jews_nagr_trd sh_jews_trd_gnrl sh_jews_crafts sh_jews_trns
	
global vars_report Ish_jews_credit_lshock_pt Ish_jews_credit_pol_turmoil ///
	Ish_jews_trd_gr_lshock_pt Ish_jews_trd_gr_pol_turmoil ///
	Ish_jews_nagr_trd_lshock_pt Ish_jews_nagr_trd_pol_turmoil ///
	Ish_jews_trd_gnrl_lshock_pt Ish_jews_trd_gnrl_pol_turmoil ///
	Ish_jews_crafts_lshock_pt Ish_jews_crafts_pol_turmoil ///
	Ish_jews_trns_lshock_pt Ish_jews_trns_pol_turmoil ///
	Ish_jews_agr_lshock_pt Ish_jews_agr_pol_turmoil
	
replace occurrence = occurrence * 100

	** 1
	
	reg occurrence ${hetero_jews} ${hetero_jews_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_credit
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_jews_credit}, ${acreg_option}
	outreg2 using table_5_panel_A_occurrence_heterogenous_results_local_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label replace					
	
	** 2
	
	reg occurrence ${hetero_jews} ${hetero_jews_trd_gr} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_trd_gr
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_jews_trd_gr}, ${acreg_option}
	outreg2 using table_5_panel_A_occurrence_heterogenous_results_local_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 3
	
	reg occurrence ${hetero_jews} ${hetero_nagr_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_nagr_trd
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_nagr_trd} , ${acreg_option}
	outreg2 using table_5_panel_A_occurrence_heterogenous_results_local_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 4

	reg occurrence ${hetero_jews} ${hetero_general_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_trd_gnrl
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_general_trd} , ${acreg_option}
	outreg2 using table_5_panel_A_occurrence_heterogenous_results_local_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 5

	reg occurrence ${hetero_jews} ${hetero_industry} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_crafts
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_industry} , ${acreg_option}
	outreg2 using table_5_panel_A_occurrence_heterogenous_results_local_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 6

	reg occurrence ${hetero_jews} ${hetero_transport} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_trns
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_transport} , ${acreg_option}
	outreg2 using table_5_panel_A_occurrence_heterogenous_results_local_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 7
	
	reg occurrence ${hetero_jews} ${hetero_agr} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_nagr_trd
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_agr} , ${acreg_option}
	outreg2 using table_5_panel_A_occurrence_heterogenous_results_local_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					
	
	** 8

	reg occurrence ${hetero_jews} ${hetero_jews_credit} ///
		${hetero_jews_trd_gr} ${hetero_agr} ///
		${hetero_nagr_trd} ${hetero_general_trd} ///
		${hetero_industry} ${hetero_transport} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews} ${hetero_jews_credit} ///
		${hetero_jews_trd_gr} ${hetero_agr} ///
		${hetero_nagr_trd} ${hetero_general_trd} ///
		${hetero_industry} ${hetero_transport}, ${acreg_option}
	outreg2 using table_5_panel_A_occurrence_heterogenous_results_local_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ///
		adds(R-squared, r_squared, Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome) ///
		nonotes nocon nor2 label append	

************** Panel B: The effects of marketwide economic shocks **************

use "$data/pogrom_complete_data_grid.dta", clear

global hetero_jews Ish_jews_mwshock_pt   

global hetero_jews_trd_gr Ish_jews_trd_gr_mwshock_pt
	
global hetero_jews_credit Ish_jews_credit_mwshock_pt
					
global hetero_nagr_trd Ish_jews_nagr_trd_mwshock_pt
	 
global hetero_general_trd Ish_jews_trd_gnrl_mwshock_pt
	 
global hetero_industry Ish_jews_crafts_mwshock_pt 
	
global hetero_transport Ish_jews_trns_mwshock_pt
 	
global hetero_agr Ish_jews_agr_mwshock_pt

keep cell_id year latitude longitude occurrence ///
	${hetero_jews} ${hetero_jews_trd_gr} ///
	${hetero_jews_credit} ${hetero_agr} ///
	${hetero_nagr_trd} ${hetero_general_trd} ///
	${hetero_industry} ${hetero_transport} ///
	sh_jews_trd_gr sh_jews_credit sh_jews_agr ///
	sh_jews_nagr_trd sh_jews_trd_gnrl sh_jews_crafts sh_jews_trns

global vars_report Ish_jews_credit_mwshock_pt Ish_jews_trd_gr_mwshock_pt ///
	Ish_jews_nagr_trd_mwshock_pt Ish_jews_trd_gnrl_mwshock_pt ///
	Ish_jews_crafts_mwshock_pt Ish_jews_trns_mwshock_pt ///
	Ish_jews_agr_mwshock_pt
	
replace occurrence = occurrence * 100
	
	** 1
	
	reg occurrence ${hetero_jews} ${hetero_jews_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_credit
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_jews_credit}, ${acreg_option}
	outreg2 using table_5_panel_B_occurrence_heterogenous_results_marketwide_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label replace					

	** 2
	
	reg occurrence ${hetero_jews} ${hetero_jews_trd_gr} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_trd_gr
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_jews_trd_gr}, ${acreg_option}
	outreg2 using table_5_panel_B_occurrence_heterogenous_results_marketwide_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 3
	
	reg occurrence ${hetero_jews} ${hetero_nagr_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_nagr_trd
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_nagr_trd}, ${acreg_option}
	outreg2 using table_5_panel_B_occurrence_heterogenous_results_marketwide_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 4

	reg occurrence ${hetero_jews} ${hetero_general_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_trd_gnrl
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_general_trd}, ${acreg_option}
	outreg2 using table_5_panel_B_occurrence_heterogenous_results_marketwide_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 5

	reg occurrence ${hetero_jews} ${hetero_industry} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_crafts
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_industry}, ${acreg_option}
	outreg2 using table_5_panel_B_occurrence_heterogenous_results_marketwide_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 6

	reg occurrence ${hetero_jews} ${hetero_transport} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_trns
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_transport}, ${acreg_option}
	outreg2 using table_5_panel_B_occurrence_heterogenous_results_marketwide_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					

	** 7
	
	reg occurrence ${hetero_jews} ${hetero_agr} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	sum sh_jews_agr
	scalar mean_var = r(mean)
	scalar sd_var = r(sd)	

	acreg occurrence ${hetero_jews} ${hetero_agr} , ${acreg_option}
	outreg2 using table_5_panel_B_occurrence_heterogenous_results_marketwide_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append					
	
	** 8

	reg occurrence ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_trd_gr} ///
		${hetero_agr} ${hetero_nagr_trd} ${hetero_general_trd} ///
		${hetero_industry} ${hetero_transport} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_trd_gr} ///
		${hetero_agr} ${hetero_nagr_trd} ${hetero_general_trd} ///
		${hetero_industry} ${hetero_transport}, ${acreg_option}
	outreg2 using table_5_panel_B_occurrence_heterogenous_results_marketwide_shocks_all_professions.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") /// 				
		adds(R-squared, r_squared, Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome) ///
		nonotes nocon nor2 label append	
