
set more off
clear all
version 14	

cd "$tables"

******* Table 7: Controlling for the measures of preexisting antisemitism ******
************************* and occupational segregation *************************

run "$do_files/ado_files/acreg.ado"
run "$do_files/ado_files/psacalc.ado"

global year_FE i.year
global cell_FE i.cell_id

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome, ///
	Delta, delta)

***************** Panel A: The effect of local economic shocks *****************
	
use "$data/pogrom_complete_data_grid.dta", clear

global hetero_jews_dummy ///
	lshock Ipol_turmoil_lshock ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  
	
global hetero_jews_credit_dummy ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///	
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil 

global hetero_jews_credit_wo_triple ///
	Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil	
	
global hetero_past_occurrence_dummy ///
	Ipast_occurrence_lshock_pt Ipast_occurrence_lshock Ipast_occurrence_pol_turmoil

global hetero_asb_literacy_dummy ///
	Inb_asb_lshock_pt Inb_asb_lshock Inb_asb_pol_turmoil ///
	Ilog_lit_non_jews_lshock_pt Ilog_lit_non_jews_lshock Ilog_lit_non_jews_pol_turmoil ///
	Illnj_nb_asb_lshock_pt Illnj_nb_asb_lshock Illnj_nb_asb_pol_turmoil ///
	Inb_book_r_lshock_pt Inb_book_r_lshock Inb_book_r_pol_turmoil 
	  
global hetero_segregation_dummy ///
	Isegreg_lshock_pt Isegreg_lshock Isegreg_pol_turmoil 

global hetero_segregation2_dummy ///
	Isegrega_lshock_pt Isegrega_lshock Isegrega_pol_turmoil  
	
keep cell_id year latitude longitude occurrence ///
	${hetero_jews_dummy} ${hetero_jews_credit_dummy} ///
	${hetero_past_occurrence_dummy} ${hetero_asb_literacy_dummy} ///
	${hetero_segregation_dummy} ${hetero_segregation2_dummy}
	
global vars_report Ish_jews_credit_lshock_pt Ish_jews_credit_pol_turmoil ///
	Ipast_occurrence_lshock_pt Ipast_occurrence_pol_turmoil ///
	Illnj_nb_asb_lshock_pt Illnj_nb_asb_pol_turmoil ///
	Isegreg_lshock_pt Isegreg_pol_turmoil ///
	Isegrega_lshock_pt Isegrega_pol_turmoil
	
replace occurrence = occurrence * 100

** max r-squared **

global r_squared_ratio = 1.3

reg occurrence ${hetero_jews_dummy} ///
	${hetero_jews_credit_dummy} ///
	${hetero_asb_literacy_dummy} ///
	${hetero_past_occurrence_dummy} ///
	${hetero_segregation_dummy} ///
	${year_FE} ${cell_FE}, cluster(cell_id)
scalar r_squared_full = e(r2)

reg occurrence ${year_FE} ${cell_FE}, cluster(cell_id)
scalar r_squared_fe = e(r2)

scalar max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * ${r_squared_ratio}
	
	** 1: baseline 
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_credit_dummy}, ${acreg_option}
	outreg2 using table_7_panel_A_occurrence_heterogenous_results_local_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ///
		adds(R-squared, r_squared, ///
			Mean of dependent var., mean_outcome, ///
			s.d. of dependent var., sd_outcome) ///
		nonotes nocon nor2 label replace					
	
	** 2: past violence
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_past_occurrence_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_credit_lshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy} ${hetero_jews_credit_wo_triple}) ///
		rmax(`r_max')
	scalar delta = r(delta)

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_credit_dummy} ///
		${hetero_past_occurrence_dummy}, ${acreg_option}
	outreg2 using table_7_panel_A_occurrence_heterogenous_results_local_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					

	** 3: antisemitic books
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_asb_literacy_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_credit_lshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy} ${hetero_jews_credit_wo_triple}) ///
		rmax(`r_max')
	scalar delta = r(delta)

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_credit_dummy} ///
		${hetero_asb_literacy_dummy}, ${acreg_option}
	outreg2 using table_7_panel_A_occurrence_heterogenous_results_local_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
	** 4: antisemitic books and past violence
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_asb_literacy_dummy} ${hetero_past_occurrence_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_credit_lshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy} ${hetero_jews_credit_wo_triple}) ///
		rmax(`r_max')
	scalar delta = r(delta)
	
	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_credit_dummy} ///
		${hetero_asb_literacy_dummy} ${hetero_past_occurrence_dummy}, ${acreg_option}
	outreg2 using table_7_panel_A_occurrence_heterogenous_results_local_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
	** 5: antisemitic books, past violence, and segregation
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_asb_literacy_dummy} ///
		${hetero_past_occurrence_dummy} ///
		${hetero_segregation_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_credit_lshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy} ${hetero_jews_credit_wo_triple}) ///
		rmax(`r_max')
	scalar delta = r(delta)
	
	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_credit_dummy} ///
		${hetero_asb_literacy_dummy} ${hetero_past_occurrence_dummy} ///
		${hetero_segregation_dummy}, ${acreg_option}
	outreg2 using table_7_panel_A_occurrence_heterogenous_results_local_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
	** 6: antisemitic books, past violence, and segregation without middleman
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_asb_literacy_dummy} ///
		${hetero_past_occurrence_dummy} ///
		${hetero_segregation2_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_credit_lshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy} ${hetero_jews_credit_wo_triple}) ///
		rmax(`r_max')
	scalar delta = r(delta)
	
	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_credit_dummy} ///
		${hetero_asb_literacy_dummy} ${hetero_past_occurrence_dummy} ///
		${hetero_segregation2_dummy}, ${acreg_option}
	outreg2 using table_7_panel_A_occurrence_heterogenous_results_local_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
************** Panel B: The effects of marketwide economic shocks **************

use "$data/pogrom_complete_data_grid.dta", clear
	
global hetero_jews_dummy Ish_jews_mwshock_pt   

global hetero_jews_trd_gr_dummy Ish_jews_trd_gr_mwshock_pt Ish_trd_gr_mwshock_pt  
	
global hetero_past_occurrence_dummy Ipast_occurrence_mwshock_pt    

global hetero_segregation_dummy Isegreg_mwshock_pt    

global hetero_segregation2_dummy Isegrega_mwshock_pt    

global hetero_asb_literacy_dummy ///
	Inb_asb_mwshock_pt Ilog_lit_non_jews_mwshock_pt ///
	Illnj_nb_asb_mwshock_pt Inb_book_r_mwshock_pt   
			
keep cell_id year latitude longitude occurrence $hetero_jews_dummy	///
	$hetero_jews_trd_gr_dummy $hetero_jews_credit_dummy ///
	$hetero_past_occurrence_dummy $hetero_asb_literacy_dummy  ///
	$hetero_segregation_dummy $hetero_segregation2_dummy

replace occurrence = occurrence * 100

global vars_report Ish_jews_trd_gr_mwshock_pt Ipast_occurrence_mwshock_pt  ///
	Illnj_nb_asb_mwshock_pt Isegreg_mwshock_pt Isegrega_mwshock_pt 
	
** max r-squared

global r_squared_ratio = 1.3

reg occurrence ${hetero_jews_dummy} ///
	${hetero_jews_trd_gr_dummy} ///
	${hetero_asb_literacy_dummy} ///
	${hetero_past_occurrence_dummy} ///
	${hetero_segregation_dummy} ///
	${year_FE} ${cell_FE}, cluster(cell_id)
scalar r_squared_full = e(r2)
	
reg occurrence ${year_FE} ${cell_FE}, cluster(cell_id)
scalar r_squared_fe = e(r2)

scalar max_r_squared = r_squared_fe + (r_squared_full-r_squared_fe) * ${r_squared_ratio}

	** 1: baseline
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_trd_gr_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_trd_gr_dummy}, ${acreg_option}
	outreg2 using table_7_panel_B_occurrence_heterogenous_results_marketwide_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ///
		adds(R-squared, r_squared, ///
			Mean of dependent var., mean_outcome, ///
			s.d. of dependent var., sd_outcome) ///
		nonotes nocon nor2 label replace					
	
	** 2: past violence
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_trd_gr_dummy} ///
		${hetero_past_occurrence_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_trd_gr_mwshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy}) ///
		rmax(`r_max')
	scalar delta = r(delta)
	scalar ratio_r_squared = max_r_squared / r_squared

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_trd_gr_dummy} ///
		${hetero_past_occurrence_dummy}, ${acreg_option}
	outreg2 using table_7_panel_B_occurrence_heterogenous_results_marketwide_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
	** 3: antisemitic books
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_trd_gr_dummy} ///
		${hetero_asb_literacy_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_trd_gr_mwshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy}) ///
		rmax(`r_max')
	scalar delta = r(delta)
	scalar ratio_r_squared = max_r_squared / r_squared

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_trd_gr_dummy} ///
		${hetero_asb_literacy_dummy}, ${acreg_option}
	outreg2 using table_7_panel_B_occurrence_heterogenous_results_marketwide_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
	** 4: antisemitic books and past violence
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_trd_gr_dummy} ///
		${hetero_asb_literacy_dummy} ///
		${hetero_past_occurrence_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_trd_gr_mwshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy}) ///
		rmax(`r_max')
	scalar delta = r(delta)
	scalar ratio_r_squared = max_r_squared / r_squared

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_trd_gr_dummy} ///
		${hetero_asb_literacy_dummy} ${hetero_past_occurrence_dummy}, ${acreg_option}
	outreg2 using table_7_panel_B_occurrence_heterogenous_results_marketwide_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
	** 5: past violence, antisemitic books, and segregation
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_trd_gr_dummy} ///
		${hetero_asb_literacy_dummy} ///
		${hetero_past_occurrence_dummy} ///
		${hetero_segregation_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_trd_gr_mwshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy}) ///
		rmax(`r_max')
	scalar delta = r(delta)
	scalar ratio_r_squared = max_r_squared / r_squared

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_trd_gr_dummy} ///
		${hetero_asb_literacy_dummy} ${hetero_past_occurrence_dummy} ///
		${hetero_segregation_dummy}, ${acreg_option}
	outreg2 using table_7_panel_B_occurrence_heterogenous_results_marketwide_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
	** 6: past violence, antisemitic books, and segregation without middleman
	
	reg occurrence ${hetero_jews_dummy} ///
		${hetero_jews_trd_gr_dummy} ///
		${hetero_asb_literacy_dummy} ///
		${hetero_past_occurrence_dummy} ///
		${hetero_segregation2_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	local r_max = max_r_squared
	psacalc delta Ish_jews_trd_gr_mwshock_pt, ///
		mcontrol(${year_FE} ${cell_FE} ${hetero_jews_dummy}) ///
		rmax(`r_max')
	scalar delta = r(delta)
	scalar ratio_r_squared = max_r_squared / r_squared

	acreg occurrence ${hetero_jews_dummy} ${hetero_jews_trd_gr_dummy} ///
		${hetero_asb_literacy_dummy} ${hetero_past_occurrence_dummy} ///
		${hetero_segregation2_dummy}, ${acreg_option}
	outreg2 using table_7_panel_B_occurrence_heterogenous_results_marketwide_shocks_w_antisemitism.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
