
set more off
clear 
version 14	

cd "$tables"

*************************** Table 8: Spatial matching **************************

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id

global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

** Panel A: The effect of treatment 1 (share of Jews among creditors above median) **
*************************************************************************************
	
global vars_report Id_sh_jews_credit_lshock_pt Ish_jews_lshock_pt Ipol_turmoil_lshock
	
********************************** Full sample *********************************
	
use "$data/pogrom_complete_data_grid.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global hetero_shock_dummy lshock Ipol_turmoil_lshock 

global hetero_jews_dummy ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit_dummy ///
	Id_sh_jews_credit_lshock_pt Id_sh_jews_credit_lshock Id_sh_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  

keep cell_id year latitude longitude occurrence ///
	${hetero_shock_dummy} ${hetero_jews_dummy} ///
	${hetero_jews_credit_dummy}
	
replace occurrence = occurrence * 100
	
	** 1
	
	reg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy}, ${acreg_option}
	outreg2 using table_8_panel_A_occurrence_results_heterogenous_local_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace			
		
*************************** Neighbors sample: credit ***************************

use "$data/data_generated/neighbors_sample_t1_wo_duplicates.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(year) pfe2(cell_id)

global dummy_credit lshock Ipol_turmoil_lshock ///
	Id_sh_jews_credit_lshock_pt Id_sh_jews_credit_pol_turmoil Id_sh_jews_credit_lshock

global dummy_credit_ext lshock Ipol_turmoil_lshock ///
	Id_sh_jews_credit_lshock_pt Id_sh_jews_credit_pol_turmoil Id_sh_jews_credit_lshock ///
	Ish_jews_lshock_pt Ish_jews_pol_turmoil Ish_jews_lshock ///
	Ish_credit_lshock_pt Ish_credit_pol_turmoil Ish_credit_lshock ///
	Ino_credit_lshock_pt Ino_credit_pol_turmoil Ino_credit_lshock 

global dummy_credit_ext2 lshock Ipol_turmoil_lshock ///
	Id_sh_jews_credit_lshock_pt Id_sh_jews_credit_pol_turmoil Id_sh_jews_credit_lshock ///
	Ish_jews_lshock_pt Ish_jews_pol_turmoil Ish_jews_lshock ///
	Ish_credit_lshock_pt Ish_credit_pol_turmoil Ish_credit_lshock ///
	Ino_credit_lshock_pt Ino_credit_pol_turmoil Ino_credit_lshock ///
	Iurban_lshock_pt Iurban_pol_turmoil Iurban_lshock 
	
global ${coordinates_credit} ///
	Ilatitude_lshock_pt Ilatitude_pol_turmoil Ilatitude_lshock ///
	Ilongitude_lshock_pt Ilongitude_pol_turmoil Ilongitude_lshock

keep cell_id year latitude longitude occurrence pweight ///
	${dummy_credit_ext2} ${coordinates_credit} pol_turmoil lshock
	
replace occurrence = occurrence * 100	
			
	** 2

	reg occurrence ${dummy_credit} ///
		${year_FE} ${cell_FE} [pw = pweight], cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_credit} [pw = pweight], ${acreg_option}
	outreg2 using table_8_panel_A_occurrence_results_heterogenous_local_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			

	** 3

	reg occurrence ${dummy_credit_ext} ///
		${year_FE} ${cell_FE} [pw = pweight], cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_credit_ext} [pw = pweight], ${acreg_option}
	outreg2 using table_8_panel_A_occurrence_results_heterogenous_local_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			

	** 4

	reg occurrence ${dummy_credit_ext2} ///
		${year_FE} ${cell_FE} [pw = pweight], cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_credit_ext2} [pw = pweight], ${acreg_option}
	outreg2 using table_8_panel_A_occurrence_results_heterogenous_local_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			

	** 5

	reg occurrence ${dummy_credit_ext2} ${coordinates_credit} ///
		${year_FE} ${cell_FE} [pw = pweight], cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_credit_ext2} ${coordinates_credit} [pw = pweight], ${acreg_option}
	outreg2 using table_8_panel_A_occurrence_results_heterogenous_local_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			

	** 6

global acreg_option spatial ///
	latitude(latitude) longitude(longitude) distcut(100) ///
	pfe1(year)

global dummy_credit_ext2 ///
	Id_sh_jews_credit_lshock_pt ///
	Ish_jews_lshock_pt ///
	Ish_credit_lshock_pt ///
	Ino_credit_lshock_pt ///
	Iurban_lshock_pt 

	reg occurrence ${dummy_credit_ext2} ///
		${year_FE} [pw = pweight] if lshock == 1 & pol_turmoil == 1, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_credit_ext2} [pw = pweight] if lshock == 1 & pol_turmoil == 1, ${acreg_option}
	outreg2 using table_8_panel_A_occurrence_results_heterogenous_local_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			

	** 7

use "$data/data_generated/neighbors_sample_t1_w_duplicates.dta", clear

global acreg_option spatial ///
	latitude(latitude) longitude(longitude) distcut(100) ///
	pfe1(year) pfe2(cell_id_n)
	
keep cell_id cell_id_n year latitude longitude occurrence ///
	${dummy_credit_ext2} lshock pol_turmoil Ipol_turmoil_lshock

replace occurrence = occurrence * 100
	
	reg occurrence ${dummy_credit_ext2} ///
		${year_FE} i.cell_id_n if lshock == 1 & pol_turmoil == 1, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_credit_ext2} if lshock == 1 & pol_turmoil == 1, ${acreg_option}
	outreg2 using table_8_panel_A_occurrence_results_heterogenous_local_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append	
		
** Panel B: The effect of treatment 2 (share of Jews among grain traders above median) **
*****************************************************************************************

global vars_report Id_sh_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt

**************************** Full sample: grain trade **************************
	
set more off

use "$data/pogrom_complete_data_grid.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
	
global hetero_jews_macro_dummy Ish_jews_mwshock_pt  

global hetero_jews_trd_gr_macro_dummy ///
	Id_sh_jews_trd_gr_mwshock_pt Ish_trd_gr_mwshock_pt  
	
keep cell_id year latitude longitude occurrence ///
	${hetero_jews_macro_dummy} ${hetero_jews_trd_gr_macro_dummy}
		
replace occurrence = occurrence * 100

	** 1

	reg occurrence ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_8_panel_B_occurrence_results_heterogenous_marketwide_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace		
	
************************* Neighbors sample: grain trade ************************/
	
use "$data/data_generated/neighbors_sample_t2_wo_duplicates.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(year) pfe2(cell_id)
	
global dummy_grain_trade Id_sh_jews_trd_gr_mwshock_pt

global dummy_grain_trade_ext ///
	Id_sh_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt Ish_trd_gr_mwshock_pt

global dummy_grain_trade_ext2 ///
	Id_sh_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt Ish_trd_gr_mwshock_pt Iurban_mwshock_pt 
	
global coordinates_grain_trade ///
	Ilatitude_mwshock_pt Ilongitude_mwshock_pt  
	
keep cell_id year latitude longitude occurrence pweight ///
	${dummy_grain_trade_ext2} ${coordinates_grain_trade} pol_turmoil mwshock
	
replace occurrence = occurrence * 100

	** 2

	reg occurrence ${dummy_grain_trade} ///
		${year_FE} ${cell_FE} [pw = pweight], cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_grain_trade} [pw = pweight], ${acreg_option}
	outreg2 using table_8_panel_B_occurrence_results_heterogenous_marketwide_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append		

	** 3

	reg occurrence ${dummy_grain_trade_ext} ///
		${year_FE} ${cell_FE} [pw = pweight], cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_grain_trade_ext} [pw = pweight], ${acreg_option}
	outreg2 using table_8_panel_B_occurrence_results_heterogenous_marketwide_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append		

	** 4

	reg occurrence ${dummy_grain_trade_ext2} ///
		${year_FE} ${cell_FE} [pw = pweight], cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_grain_trade_ext2} [pw = pweight], ${acreg_option}
	outreg2 using table_8_panel_B_occurrence_results_heterogenous_marketwide_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append		

	** 5

	reg occurrence ${dummy_grain_trade_ext2} $coordinates_grain_trade ///
		${year_FE} ${cell_FE} [pw = pweight], cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_grain_trade_ext2} $coordinates_grain_trade [pw = pweight], ${acreg_option}
	outreg2 using table_8_panel_B_occurrence_results_heterogenous_marketwide_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append		

	** 6

	global acreg_option spatial ///
		latitude(latitude) longitude(longitude) distcut(100) ///
		pfe1(year)

	reg occurrence ${dummy_grain_trade_ext2} ///
		${year_FE} [pw = pweight] if mwshock == 1 & pol_turmoil == 1, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_grain_trade_ext2} [pw = pweight] if mwshock == 1 & pol_turmoil == 1, ${acreg_option}
	outreg2 using table_8_panel_B_occurrence_results_heterogenous_marketwide_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append		

** 7

use "$data/data_generated/neighbors_sample_t2_w_duplicates.dta", clear

global acreg_option spatial ///
	latitude(latitude) longitude(longitude) distcut(100) ///
	pfe1(year) pfe2(cell_id_n)
	
keep cell_id cell_id_n year latitude longitude occurrence ///
	${dummy_grain_trade_ext2} pol_turmoil mwshock

replace occurrence = occurrence * 100

	reg occurrence ${dummy_grain_trade_ext2} ///
		${year_FE} i.cell_id_n if mwshock == 1 & pol_turmoil == 1, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
		
	acreg occurrence ${dummy_grain_trade_ext2} if mwshock == 1 & pol_turmoil == 1, ${acreg_option}
	outreg2 using table_8_panel_B_occurrence_results_heterogenous_marketwide_shocks_neighbors.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append		
