
set more off
clear 
version 14

cd "$tables"

******** Table 9: Robustness to changes in the sample, aggregation, and ********
***** definition of political turmoil, and the construction of climate data ****

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id
global cell_1d_FE i.id
global uezd_FE i.uezd_code_num

global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)
	
global vars_report Ish_jews_credit_lshock_pt Ish_jews_trd_gr_mwshock_pt ///
	Ipol_turmoil_lshock

** 1

use "$data/pogrom_complete_data_grid.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global hetero_shock lshock Ipol_turmoil_lshock 

global hetero_jews ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  	
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt    

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt    
	
keep cell_id year latitude longitude occurrence ///
	${hetero_shock} ${hetero_jews}	///
	${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} 
	
replace occurrence = occurrence * 100	
		
	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE} if !(year >= 1880 & year <= 1882), cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} ///
		if !(year >= 1880 & year <= 1882), ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace					
	
** 2

use "$data/pogrom_complete_data_grid.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global hetero_shock hot_sp5 Ipol_turmoil_hot_sp5 

global hetero_jews Ish_jews_hot_sp5_pt Ish_jews_hot_sp5 Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_hot_sp5_pt Ish_jews_credit_hot_sp5 Ish_jews_credit_pol_turmoil ///
	Ish_credit_hot_sp5_pt Ish_credit_hot_sp5 Ish_credit_pol_turmoil ///
	Ino_credit_hot_sp5_pt Ino_credit_hot_sp5 Ino_credit_pol_turmoil  
	
global hetero_jews_mrktwide Ish_jews_mshock_pt  
  
global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mshock_pt ///
	Ish_trd_gr_mshock_pt    
	
keep cell_id year latitude longitude occurrence ///
	${hetero_shock} ${hetero_jews}	///
	${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} 

rename *hot_sp5* *lshock*	
rename *_mshock* *_mwshock*	

global hetero_shock lshock Ipol_turmoil_lshock 

global hetero_jews Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  	
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt    

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt    
	
replace occurrence = occurrence * 100	
		
	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					

** 3

use "$data/pogrom_complete_data_grid.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global hetero_shock lshock Ipol_turmoil2_lshock 

global hetero_jews Ish_jews_lshock_pt2 Ish_jews_lshock Ish_jews_pol_turmoil2 

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt2 Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil2 ///
	Ish_credit_lshock_pt2 Ish_credit_lshock Ish_credit_pol_turmoil2 ///
	Ino_credit_lshock_pt2 Ino_credit_lshock Ino_credit_pol_turmoil2  
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt2 
   
global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt2 ///
	Ish_trd_gr_mwshock_pt2    	

keep cell_id year latitude longitude occurrence ///
	${hetero_shock} ${hetero_jews}	///
	${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} 

rename *pol_turmoil2* *pol_turmoil*	
rename *_pt2* *_pt*	

global hetero_shock lshock Ipol_turmoil_lshock 

global hetero_jews Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  	
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt    

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt      

replace occurrence = occurrence * 100	
	
	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					

** 4

use "$data/pogrom_complete_data_grid.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global hetero_shock lshock Ipol_turmoil3_lshock 

global hetero_jews Ish_jews_lshock_pt3 Ish_jews_lshock Ish_jews_pol_turmoil3 

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt3 Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil3 ///
	Ish_credit_lshock_pt3 Ish_credit_lshock Ish_credit_pol_turmoil3 ///
	Ino_credit_lshock_pt3 Ino_credit_lshock Ino_credit_pol_turmoil3  
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt3   
 
global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt3 ///
	Ish_trd_gr_mwshock_pt3    	

keep cell_id year latitude longitude occurrence ///
	${hetero_shock} ${hetero_jews}	///
	${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} 

rename *pol_turmoil3* *pol_turmoil*	
rename *_pt3* *_pt*	

global hetero_shock lshock Ipol_turmoil_lshock 

global hetero_jews Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  	
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt    

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt     
				
replace occurrence = occurrence * 100	

	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
** 5

use "$data/pogrom_complete_data_grid.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global hetero_shock lshock Ipol_turmoil4_lshock 

global hetero_jews Ish_jews_lshock_pt4 Ish_jews_lshock Ish_jews_pol_turmoil4 

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt4 Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil4 ///
	Ish_credit_lshock_pt4 Ish_credit_lshock Ish_credit_pol_turmoil4 ///
	Ino_credit_lshock_pt4 Ino_credit_lshock Ino_credit_pol_turmoil4
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt4  
  
global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt4 ///
	Ish_trd_gr_mwshock_pt4    	

keep cell_id year latitude longitude occurrence ///
	${hetero_shock} ${hetero_jews}	///
	${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} 

rename *pol_turmoil4* *pol_turmoil*	
rename *_pt4* *_pt*	

global hetero_shock lshock Ipol_turmoil_lshock 

global hetero_jews Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  	
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt    

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt     
				
replace occurrence = occurrence * 100	

	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
		
** 6

use "$data/pogrom_complete_data_grid.dta", clear

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)

global hetero_shock lshock Ipol_turmoil_lshock 

global hetero_jews Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  	
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt    

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt      

keep cell_id year latitude longitude occurrence capital ///
	${hetero_shock} ${hetero_jews}	///
	${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} 
	
replace occurrence = occurrence * 100	

	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE} if year > 1861, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} if year > 1861, ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
	
** 7
	
	reg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_FE} if capital == 0, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock} ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} if capital == 0, ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					

** 8

use "$data/table_9_pogrom_complete_data_grid_1degree.dta", clear

global acreg_option id(id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid1degree} ///
	pfe1(id) pfe2(year)

global hetero_jews lshock Ipol_turmoil_lshock ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt  

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt  
	
keep id year latitude longitude occurrence ///
	${hetero_jews} ${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} 
		
replace occurrence = occurrence * 100	

	reg occurrence ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${cell_1d_FE}, cluster(id)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					

** 9

use "$data/table_9_pogrom_complete_data_uezd.dta", clear

global acreg_option id(uezd_code) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_uezd} ///
	pfe1(uezd_code_num) pfe2(year)

global hetero_jews lshock Ipol_turmoil_lshock ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  
	
global hetero_jews_mrktwide Ish_jews_mwshock_pt  

global hetero_jews_trd_gr_mrktwide ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt  
	
keep uezd_code* year latitude longitude occurrence ///
	${hetero_jews} ${hetero_jews_credit} ///
	${hetero_jews_mrktwide} ${hetero_jews_trd_gr_mrktwide} 
		
replace occurrence = occurrence * 100	

	reg occurrence ${hetero_jews} ///
		${hetero_jews_credit} ///
		${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide} ///
		${year_FE} ${uezd_FE}, cluster(uezd_code_num)
	scalar r_squared = e(r2)
		
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews} ///
		${hetero_jews_credit} ${hetero_jews_mrktwide} ///
		${hetero_jews_trd_gr_mrktwide}, ${acreg_option}
	outreg2 using table_9_occurrence_results_heterogenous_local_market_wide_shocks_robustness.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append					
