
set more off
clear 
version 14

cd "$tables"

***************** Table A1, Panel A: Share of major occupations ****************
	
use "$data/pogrom_complete_data_grid.dta", clear

keep sh_credit sh_trd sh_agr_int_pr sh_trd_gr sh_nagr_trd sh_crafts ///
	sh_trns sh_agr no_credit capital urbanization cell_id 
duplicates drop

sutex 	sh_credit sh_trd sh_agr_int_pr sh_trd_gr sh_nagr_trd sh_crafts ///
		sh_trns sh_agr no_credit capital urbanization, ///
		nobs minmax label digits(4) ///
		file(table_a1_descriptive_statistics_appendix.tex) replace	
		
**** Table A1, Panel B: Occurrence of local econ shock and political turmoil ****

use "$data/pogrom_complete_data_grid.dta", clear

sutex 	lshock mwshock pol_turmoil Ipol_turmoil_lshock Ipol_turmoil_mwshock, ///
		nobs minmax label digits(4) ///
		file(table_a1_descriptive_statistics_appendix.tex) append	

******************* Table A1, Panel C: Grain yield and price *******************

use "$data/grain_price_harvest_complete_data_gubernia.dta", clear
	
keep gub_id year grain_price grain_harvest
duplicates drop

sutex 	grain_harvest grain_price , ///
		nobs minmax label digits(1) ///
		file(table_a1_descriptive_statistics_appendix.tex) append	
		
********** Table A1, Panel D: Sovereign bond yield spread across years *********

use "$data/pogrom_complete_data_grid.dta", clear

keep if d_bspready != .

keep bspread d_bspready
duplicates drop

lab var bspread "Average yearly sovereign bond spread yield"
lab var d_bspready "Years with rising sovereign bond spread yield"

sutex 	bspread d_bspready, ///
		nobs minmax label digits(4) ///
		file(table_a1_descriptive_statistics_appendix.tex) append	
		
********** Table A1, Panel E: Anti-semitism nad literacy of non-Jews ***********

use "$data/pogrom_complete_data_grid.dta", clear

keep cell_id asb_rf nb_book_r nb_asb past_occurrence ///
	sh_lit_non_jews log_lit_non_jews segreg segrega
duplicates drop

sutex 	past_occurrence asb_rf nb_book_r nb_asb sh_lit_non_jews log_lit_non_jews ///
		segreg segrega, nobs minmax label digits(4) ///
		file(table_a1_descriptive_statistics_appendix.tex) append	

*************************** Table A1, Panel F: Crime ***************************

use "$data/pogrom_complete_data_grid.dta", clear

keep if year >= 1900 & year <= 1912

keep theft_pc homicide_pc arson_pc cell_id
duplicates drop

sutex 	theft_pc homicide_pc arson_pc, ///
		nobs minmax label digits(2) ///
		file(table_a1_descriptive_statistics_appendix.tex) append	
