
set more off
clear 
version 14

cd "$tables"

** Table A10: Balance test across treated and control cells in the matched sample **

run "$do_files/ado_files/acreg.ado"

global acreg_option spatial ///
	latitude(latitude) longitude(longitude) distcut(100) 
	
global add_stat adds(R-squared, r_squared)
	
global var_balance rye_suitability ///
	past_occurrence asb_rf sh_lit_jews sh_lit_non_jews ///
	sh_lit_diff sh_catholic sh_agr 

** Panel A: The effect of treatment 1 (share of Jews among creditors above median) **

use "$data/data_generated/neighbors_sample_t1_wo_duplicates.dta", clear

keep cell_id latitude longitude year d_sh_jews_credit sh_jews sh_credit sh_trd_gr ///
	${var_balance} urban lshock pol_turmoil pweight

keep if lshock == 1 & pol_turmoil == 1
	
	** unconditional **

	reg sh_jews d_sh_jews_credit [pw = pweight], robust
	scalar r_squared = e(r2)
	
	acreg sh_jews d_sh_jews_credit [pw = pweight], $acreg_option
	outreg2 using table_a10_panel_A_neighbors_balance_test_local_shocks.xls, ///
		tex(frag) excel bdec(4) tdec(4) sdec(4) ///
		${add_stat} nonotes nocon nor2 label replace
	
	foreach var in sh_credit sh_trd_gr $var_balance urban {

		reg `var' d_sh_jews_credit [pw = pweight], robust
		scalar r_squared = e(r2)
			
		acreg `var' d_sh_jews_credit [pw = pweight], $acreg_option
		outreg2 using table_a10_panel_A_neighbors_balance_test_local_shocks.xls, ///
			tex(frag) excel bdec(4) tdec(4) sdec(4) ///
			${add_stat} nonotes nocon nor2 label append	
		}
		
	** conditional on urbanization rate **

	reg sh_jews d_sh_jews_credit urban [pw = pweight], robust
	scalar r_squared = e(r2)
	
	acreg sh_jews d_sh_jews_credit urban [pw = pweight], $acreg_option
	outreg2 using table_a10_panel_A_neighbors_balance_test_local_shocks_w_urbanization.xls, ///
		tex(frag) excel bdec(4) tdec(4) sdec(4) ///
		${add_stat} nonotes nocon nor2 label replace

	foreach var in sh_credit sh_trd_gr $var_balance {
	
		reg `var' d_sh_jews_credit urban [pw = pweight], robust
		scalar r_squared = e(r2)
				
		acreg `var' d_sh_jews_credit urban [pw = pweight], $acreg_option
		outreg2 using table_a10_panel_A_neighbors_balance_test_local_shocks_w_urbanization.xls, ///
			tex(frag) excel bdec(4) tdec(4) sdec(4) ///
			${add_stat} nonotes nocon nor2 label append	
	}

** Panel B: The effect of treatment 2 (share of Jews among grain traders above median) **

use "$data/data_generated/neighbors_sample_t2_wo_duplicates.dta", clear

keep cell_id latitude longitude year d_sh_jews_trd_gr sh_jews sh_credit sh_trd_gr ///
	${var_balance} urban mwshock pol_turmoil pweight

keep if mwshock == 1 & pol_turmoil == 1
			
	** unconditional **
	
	reg sh_jews d_sh_jews_trd_gr [pw = pweight], robust
	scalar r_squared = e(r2)
	
	acreg sh_jews d_sh_jews_trd_gr [pw = pweight], $acreg_option
	outreg2 using table_a10_panel_B_neighbors_balance_test_markewide_shocks.xls, ///
		tex(frag) excel bdec(4) tdec(4) sdec(4) ///
		${add_stat} nonotes nocon nor2 label replace

	foreach var in sh_credit sh_trd_gr $var_balance urban {
				
		if "`var'" == "past_occurrence" {
			reg `var' d_sh_jews_trd_gr [pw = pweight], robust
			scalar r_squared = e(r2)
			
			acreg `var' d_sh_jews_trd_gr [pw = pweight], spatial ///
				latitude(latitude) longitude(longitude) distcut(50) 
			outreg2 using table_a10_panel_B_neighbors_balance_test_markewide_shocks.xls, ///
				tex(frag) excel bdec(4) tdec(4) sdec(4) ///
				${add_stat} nonotes nocon nor2 label append	
			}
			
		else {		
			reg `var' d_sh_jews_trd_gr [pw = pweight], robust
			scalar r_squared = e(r2)
			
			acreg `var' d_sh_jews_trd_gr [pw = pweight], $acreg_option
			outreg2 using table_a10_panel_B_neighbors_balance_test_markewide_shocks.xls, ///
				tex(frag) excel bdec(4) tdec(4) sdec(4) ///
				${add_stat} nonotes nocon nor2 label append	
			}	

		}
		
	** conditional on urbanization rate **
	
	reg sh_jews d_sh_jews_trd_gr urban [pw = pweight], robust
	scalar r_squared = e(r2)
		
	acreg sh_jews d_sh_jews_trd_gr urban [pw = pweight], $acreg_option
	outreg2 using table_a10_panel_B_neighbors_balance_test_markewide_shocks_w_urbanization.xls, ///
		tex(frag) excel bdec(4) tdec(4) sdec(4) ///
		${add_stat} nonotes nocon nor2 label replace

	foreach var in sh_credit sh_trd_gr $var_balance {
	
		if "`var'" == "past_occurrence" {
			reg `var' d_sh_jews_trd_gr urban [pw = pweight], robust
			scalar r_squared = e(r2)
			
			acreg `var' d_sh_jews_trd_gr urban [pw = pweight], spatial ///
				latitude(latitude) longitude(longitude) distcut(50) 
			outreg2 using table_a10_panel_B_neighbors_balance_test_markewide_shocks_w_urbanization.xls, ///
				tex(frag) excel bdec(4) tdec(4) sdec(4) ///
				${add_stat} nonotes nocon nor2 label append	
			}	
		
		else{
			reg `var' d_sh_jews_trd_gr urban [pw = pweight], robust
			scalar r_squared = e(r2)
			
			acreg `var' d_sh_jews_trd_gr urban [pw = pweight], $acreg_option
			outreg2 using table_a10_panel_B_neighbors_balance_test_markewide_shocks_w_urbanization.xls, ///
				tex(frag) excel bdec(4) tdec(4) sdec(4) ///
				${add_stat} nonotes nocon nor2 label append	
			}	
	}
