
set more off
clear 
version 14	

cd "$tables"

** Table A11: Robustness to using a continuous measure of local economic shock **
		
use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

global hetero_shock_sdev sdev_temp_sp_rm75 Ipol_turmoil_temp_sp 

global hetero_jews_sdev Ish_jews_temp_sp Ish_jews_pol_turmoil Ish_jews_temp_sp_pt ///
	Icapital_temp_sp_pt Icapital_temp_sp Icapital_pol_turmoil  
	
global hetero_jews_credit_sdev ///
	Ish_jews_credit_temp_sp_pt Ish_jews_credit_temp_sp Ish_jews_credit_pol_turmoil  ///
	Ino_credit_temp_sp_pt Ino_credit_temp_sp Ino_credit_pol_turmoil 
	
global hetero_jews_trd_gr_sdev ///
	Ish_jews_trd_gr_temp_sp_pt Ish_jews_trd_gr_temp_sp Ish_jews_trd_gr_pol_turmoil 
	
global hetero_jews_trd_gr_macro_dummy ///
	Ish_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt Icapital_mwshock_pt  
			
keep cell_id year latitude longitude occurrence ///
	${hetero_shock_sdev} ${hetero_jews_sdev} ///
	${hetero_jews_trd_gr_sdev} ${hetero_jews_credit_sdev} ///
	${hetero_jews_trd_gr_macro_dummy}

global vars_report sdev_temp_sp_rm75 Ipol_turmoil_temp_sp  ///
	Ish_jews_temp_sp_pt Ish_jews_temp_sp Ish_jews_pol_turmoil  ///
	Ish_jews_credit_temp_sp_pt Ish_jews_credit_temp_sp Ish_jews_credit_pol_turmoil ///
	Ish_jews_trd_gr_temp_sp_pt Ish_jews_trd_gr_temp_sp Ish_jews_trd_gr_pol_turmoil ///
	Ish_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt

replace occurrence = occurrence * 100

lab var sdev_temp_sp_rm75 "Dev spring temperature"
	
	** 1

	xi: reg occurrence sdev_temp_sp_rm75 ///
		${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)

	keep if e(sample)

	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)

	acreg occurrence sdev_temp_sp_rm75, ${acreg_option_wo_YFE}
	outreg2 using table_a11_occurrence_results_heterogenous_continuous_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label replace	

	** 2

	xi: reg occurrence sdev_temp_sp_rm75 ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)

	keep if e(sample)

	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)

	acreg occurrence sdev_temp_sp_rm75, ${acreg_option}
	outreg2 using table_a11_occurrence_results_heterogenous_continuous_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append
		
	** 3

	xi: reg occurrence sdev_temp_sp_rm75 Ipol_turmoil_temp_sp ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)

	keep if e(sample)

	sum occurrence if e(sample)
		scalar mean_outcome = r(mean)
		scalar sd_outcome = r(sd)

	acreg occurrence sdev_temp_sp_rm75 Ipol_turmoil_temp_sp, ${acreg_option}
	outreg2 using table_a11_occurrence_results_heterogenous_continuous_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append
		
	** 4

	reg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev}, ${acreg_option}
	outreg2 using table_a11_occurrence_results_heterogenous_continuous_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append

	** 5

	reg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${hetero_jews_credit_sdev} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${hetero_jews_credit_sdev}, ${acreg_option}
	outreg2 using table_a11_occurrence_results_heterogenous_continuous_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append

	** 6

	reg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${hetero_jews_credit_sdev} ///
		${hetero_jews_trd_gr_sdev}  ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${hetero_jews_credit_sdev} ${hetero_jews_trd_gr_sdev}, ${acreg_option}
	outreg2 using table_a11_occurrence_results_heterogenous_continuous_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append

	** 7

	reg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${hetero_jews_trd_gr_sdev} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${hetero_jews_trd_gr_sdev}, ${acreg_option}
	outreg2 using table_a11_occurrence_results_heterogenous_continuous_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append

	** 8
					
	reg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${hetero_jews_credit_sdev} ///
		${hetero_jews_trd_gr_macro_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_sdev} ${hetero_jews_sdev} ///
		${hetero_jews_credit_sdev} ${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a11_occurrence_results_heterogenous_continuous_local_marketwide_shocks.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogrom") ${add_stat} nonotes nocon nor2 label append		
