
set more off
clear 
version 14

cd "$tables"

** Table A12: Logs of the numbers of Jewish creditors and grain traders **

use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id

global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

global hetero_shock_dummy lshock Ipol_turmoil_lshock 

global hetero_jews_dummy ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil 
 
global hetero_jews_credit_dummy ///
	Ilog_jews_credit_lshock_pt Ilog_jews_credit_lshock Ilog_jews_credit_pol_turmoil ///
	Ilog_pop_credit_lshock_pt Ilog_pop_credit_lshock Ilog_pop_credit_pol_turmoil ///
	Ilog_tot_pop_lshock_pt Ilog_tot_pop_lshock Ilog_tot_pop_pol_turmoil 
	
global hetero_jews_trd_gr_dummy ///
	Ilog_jews_trd_gr_lshock_pt Ilog_jews_trd_gr_lshock Ilog_jews_trd_gr_pol_turmoil ///
	Ilog_pop_trd_gr_lshock_pt Ilog_pop_trd_gr_lshock Ilog_pop_trd_gr_pol_turmoil ///
	Ilog_tot_pop_lshock_pt Ilog_tot_pop_lshock Ilog_tot_pop_pol_turmoil 
	
global hetero_jews_macro_dummy ///
	Ish_jews_mwshock_pt Ish_jews_mwshock Ish_jews_pol_turmoil 
 
global hetero_jews_trd_gr_macro_dummy ///
	Ilog_jews_trd_gr_mwshock_pt Ilog_jews_trd_gr_mwshock Ilog_jews_trd_gr_pol_turmoil ///
	Ilog_pop_trd_gr_mwshock_pt Ilog_pop_trd_gr_mwshock Ilog_pop_trd_gr_pol_turmoil /// 
	Ilog_tot_pop_mwshock_pt Ilog_tot_pop_mwshock Ilog_tot_pop_pol_turmoil 

keep cell_id year latitude longitude occurrence ///
	${hetero_shock_dummy} ${hetero_jews_dummy}	///
	${hetero_jews_trd_gr_dummy} ${hetero_jews_credit_dummy} ///
	${hetero_jews_macro_dummy} ${hetero_jews_trd_gr_macro_dummy}
		
global vars_report Ilog_jews_credit_lshock_pt ///
	Ilog_jews_trd_gr_lshock_pt Ilog_jews_trd_gr_mwshock_pt ///
	Ilog_jews_credit_pol_turmoil Ilog_jews_credit_lshock ///
	Ilog_jews_trd_gr_pol_turmoil Ilog_jews_trd_gr_lshock ///
	Ilog_jews_trd_gr_mwshock Ipol_turmoil_lshock Ish_jews_lshock_pt

replace occurrence = occurrence * 100
	
	** 1 

	reg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy}, ${acreg_option}
	outreg2 using table_a12_occurrence_results_heterogenous_local_marketwide_shocks_log.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace			

	** 2

	reg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_trd_gr_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
				
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_trd_gr_dummy}, ${acreg_option}
	outreg2 using table_a12_occurrence_results_heterogenous_local_marketwide_shocks_log.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			

	** 3

	reg occurrence ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a12_occurrence_results_heterogenous_local_marketwide_shocks_log.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			

	** 4
			
	global hetero_jews_macro_dummy Ish_jews_mwshock_pt  
	global hetero_jews_trd_gr_macro_dummy Ilog_jews_trd_gr_mwshock_pt   ///
		Ilog_pop_trd_gr_mwshock_pt Ilog_tot_pop_mwshock_pt

	reg occurrence ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a12_occurrence_results_heterogenous_local_marketwide_shocks_log.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			

	** 5
	
	reg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a12_occurrence_results_heterogenous_local_marketwide_shocks_log.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append			
		
