
set more off
clear 
version 14	

cd "$tables"

** Table A13: Robustness to different assumptions about the variance-covariance matrix **

use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id
		
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

global hetero_shock_dummy lshock Ipol_turmoil_lshock 

global hetero_jews_dummy ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil  

global hetero_jews_credit_dummy ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil  
	
global hetero_jews_macro_dummy Ish_jews_mwshock_pt   
 
global hetero_jews_trd_gr_macro_dummy ///
	Ish_jews_trd_gr_mwshock_pt ///
	Ish_trd_gr_mwshock_pt    	
	
keep cell_id uezd_code2 gub_id year latitude longitude occurrence ///
	${hetero_shock_dummy} ${hetero_jews_dummy}	///
	${hetero_jews_credit_dummy} ///
	${hetero_jews_macro_dummy} ${hetero_jews_trd_gr_macro_dummy} 
	
global vars_report Ish_jews_credit_lshock_pt Ish_jews_trd_gr_mwshock_pt ///
	 Ish_jews_lshock_pt Ipol_turmoil_lshock

replace occurrence = occurrence * 100

	** R-squared and summary stats
	
	reg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	** 1
	
	global acreg_option id(cell_id) time(year) spatial ///
		latitude(latitude) longitude(longitude) ///
		dist(50) lag(1) lagdist(0) hac ///
		pfe1(cell_id) pfe2(year)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("50 km, 1 lag") ${add_stat} nonotes nocon nor2 label replace					
	
	** 2
	
	global acreg_option id(cell_id) time(year) spatial ///
		latitude(latitude) longitude(longitude) ///
		dist(200) lag(1) lagdist(0) hac ///
		pfe1(cell_id) pfe2(year)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("200 km, 1 lag") ${add_stat} nonotes nocon nor2 label append					
	
	** 3
	
	global acreg_option id(cell_id) time(year) spatial ///
		latitude(latitude) longitude(longitude) ///
		dist(500) lag(1) lagdist(0) hac ///
		pfe1(cell_id) pfe2(year)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("500 km, 1 lag") ${add_stat} nonotes nocon nor2 label append	
	
	** 4
	
	global acreg_option id(cell_id) time(year) spatial ///
		latitude(latitude) longitude(longitude) ///
		dist(100) lag(3) lagdist(0) hac ///
		pfe1(cell_id) pfe2(year)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("100 km, 3 lag") ${add_stat} nonotes nocon nor2 label append					
	
	** 5
	
	global acreg_option id(cell_id) time(year) spatial ///
		latitude(latitude) longitude(longitude) ///
		dist(100) lag(5) lagdist(0) hac ///
		pfe1(cell_id) pfe2(year)
	
	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("100 km, 5 lag") ${add_stat} nonotes nocon nor2 label append					
	
	** 6
	
	global acreg_option id(cell_id) time(year) spatial ///
		latitude(latitude) longitude(longitude) ///
		dist(100) lag(10) lagdist(0) hac ///
		pfe1(cell_id) pfe2(year)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("100 km, 10 lag") ${add_stat} nonotes nocon nor2 label append					
	
	** 7
	
	global acreg_option id(cell_id) time(year) spatial ///
		latitude(latitude) longitude(longitude) ///
		dist(500) lag(10) lagdist(0) hac ///
		pfe1(cell_id) pfe2(year)

	acreg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy}, ${acreg_option}
	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("500 km, 10 lag") ${add_stat} nonotes nocon nor2 label append					
	
	** 8
			
	reg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("cluster, grid") ${add_stat} nonotes nocon label append					

	** 9
	
	encode uezd_code2, gen(uezd_num)
			
	reg occurrence ${hetero_shock_dummy} ${hetero_jews_dummy} ///
		${hetero_jews_credit_dummy} ///
		${hetero_jews_macro_dummy} ///
		${hetero_jews_trd_gr_macro_dummy} ///
		${year_FE} ${cell_FE}, cluster(uezd_num)
		
	sum occurrence
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	outreg2 using table_a13_occurrence_results_heterogenous_local_marketwide_shocks_robustness_VCV.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("cluster, district") ${add_stat} nonotes nocon label append					
