
set more off
clear 
version 14	

cd "$tables"

*** Table A14: Robustness to controlling for the presence of other minorities ***

use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id
		
global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)
	
global hetero_credit_dummy ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil ///
	lshock Ipol_turmoil_lshock

global hetero_grain_trd_dummy ///
	Ish_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt Ish_trd_gr_mwshock_pt
			
global hetero_germans_credit ///
	Ish_ger_lshock_pt Ish_ger_lshock Ish_ger_pol_turmoil
			
global hetero_germans2_credit ///
	Ish_ger_credit_lshock_pt Ish_ger_credit_lshock Ish_ger_credit_pol_turmoil 

global hetero_russians_credit ///
	Ish_rus_lshock_pt Ish_rus_lshock Ish_rus_pol_turmoil
			
global hetero_russians2_credit ///
	Ish_rus_credit_lshock_pt Ish_rus_credit_lshock Ish_rus_credit_pol_turmoil 
				
global hetero_minority2_credit ///
	Ish_min1_credit_lshock_pt Ish_min1_credit_lshock Ish_min1_credit_pol_turmoil 
	
global hetero_germans_grain_trd Ish_ger_mwshock_pt 
			
global hetero_germans2_grain_trd Ish_ger_trd_gr_mwshock_pt 
	
global hetero_russians_grain_trd Ish_rus_mwshock_pt
			
global hetero_russians2_grain_trd Ish_rus_trd_gr_mwshock_pt
				
global hetero_minority2_grain_trd Ish_min1_trd_gr_mwshock_pt

keep occurrence latitude longitude year cell_id ///
	${hetero_credit_dummy} ${hetero_grain_trd_dummy} ///
	${hetero_germans_credit} ${hetero_germans2_credit} ///
	${hetero_russians_credit} ${hetero_russians2_credit} ///
	${hetero_minority2_credit} ///
	${hetero_germans_grain_trd} ${hetero_germans2_grain_trd} ///
	${hetero_russians_grain_trd} $hetero_russians2_grain_trd ///
	${hetero_minority2_grain_trd} 
	
replace occurrence = occurrence * 100	
		
***************** Panel A: The effects of local economic shock *****************	
		
global vars_report Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	${hetero_germans_credit} ${hetero_germans2_credit} ///
	${hetero_russians_credit} ${hetero_russians2_credit} ///
	${hetero_minority2_credit}
	
	** 1
	
	reg occurrence ${hetero_credit_dummy} ${hetero_germans_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_germans_credit}, ${acreg_option}
	outreg2 using table_a14_panel_A_occurrence_results_heterogenous_local_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace

	** 2
	
	reg occurrence ${hetero_credit_dummy} ${hetero_germans2_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_germans2_credit}, ${acreg_option}
	outreg2 using table_a14_panel_A_occurrence_results_heterogenous_local_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append
			
	** 3
	
	reg occurrence ${hetero_credit_dummy} ${hetero_russians_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_russians_credit}, ${acreg_option}
	outreg2 using table_a14_panel_A_occurrence_results_heterogenous_local_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append

	** 4
	
	reg occurrence ${hetero_credit_dummy} ${hetero_russians2_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_russians2_credit}, ${acreg_option}
	outreg2 using table_a14_panel_A_occurrence_results_heterogenous_local_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append
		
	** 5
	
	reg occurrence ${hetero_credit_dummy} ${hetero_minority2_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_minority2_credit}, ${acreg_option}
	outreg2 using table_a14_panel_A_occurrence_results_heterogenous_local_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append
		
************** Panel B: The effects of marketwide economic shock ***************
		
global vars_report Ish_jews_trd_gr_mwshock_pt ///
	${hetero_germans_grain_trd} ${hetero_germans2_grain_trd} ///
	${hetero_russians_grain_trd} ${hetero_russians2_grain_trd} ///
	${hetero_minority2_grain_trd}

	** 1
	
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_germans_grain_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_germans_grain_trd}, ${acreg_option}
	outreg2 using table_a14_panel_B_occurrence_results_heterogenous_marketwide_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace

	** 2
	
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_germans2_grain_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_germans2_grain_trd}, ${acreg_option}
	outreg2 using table_a14_panel_B_occurrence_results_heterogenous_marketwide_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append
		
	** 3
	 
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_russians_grain_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_russians_grain_trd}, ${acreg_option}
	outreg2 using table_a14_panel_B_occurrence_results_heterogenous_marketwide_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append

	** 4
	
	reg occurrence ${hetero_grain_trd_dummy} $hetero_russians2_grain_trd ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} $hetero_russians2_grain_trd, ${acreg_option}
	outreg2 using table_a14_panel_B_occurrence_results_heterogenous_marketwide_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append

	** 5
	
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_minority2_grain_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_minority2_grain_trd}, ${acreg_option}
	outreg2 using table_a14_panel_B_occurrence_results_heterogenous_marketwide_shocks_robustness_other_ethnicities.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append
