
set more off
clear 
version 14	

cd "$tables"

** Table A15: Potential heterogenous effects of specialization of Jews as middlaman **

use "$data/pogrom_complete_data_grid.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global cell_FE i.cell_id
				
global acreg_option id(cell_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_grid} ///
	pfe1(cell_id) pfe2(year)
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

** main effects

global hetero_credit_dummy ///
	Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Ish_jews_lshock_pt Ish_jews_lshock Ish_jews_pol_turmoil ///
	Ish_credit_lshock_pt Ish_credit_lshock Ish_credit_pol_turmoil ///
	Ino_credit_lshock_pt Ino_credit_lshock Ino_credit_pol_turmoil ///
	lshock Ipol_turmoil_lshock
	
global hetero_grain_trd_dummy ///
	Ish_jews_trd_gr_mwshock_pt Ish_jews_mwshock_pt Ish_trd_gr_mwshock_pt
	
** quadruple interactions with share of jews in credit
		 
global hetero_agr_commerce_credit ///
	Iagr_com_lshock_pt Iagr_com_lshock Iagr_com_pol_turmoil ///
	Isjc_agr_com_lshock_pt Isjc_agr_com_lshock Isjc_agr_com_pol_turmoil

global hetero_railways_credit ///
	Id2rail_lshock_pt Id2rail_lshock Id2rail_pol_turmoil ///
	Isjc_d2rail_lshock_pt Isjc_d2rail_lshock Isjc_d2rail_pol_turmoil

global hetero_tax_rate_credit ///
	Itax_rate_lshock_pt Itax_rate_lshock Itax_rate_pol_turmoil ///  
	Isjc_tax_rate_lshock_pt Isjc_tax_rate_lshock Isjc_tax_rate_pol_turmoil  

global hetero_lgini_credit ///
	Ilgini_lshock_pt Ilgini_lshock Ilgini_pol_turmoil /// 
	Isjc_lgini_lshock_pt Isjc_lgini_lshock Isjc_lgini_pol_turmoil 

** quadruple interactions with share of jews in grain trade

global hetero_agr_commerce_grain_trd Iagr_com_mwshock_pt Isjt_agr_com_mwshock_pt
	
global hetero_railways_grain_trd Id2rail_mwshock_pt Isjt_d2rail_mwshock_pt

global hetero_tax_rate_grain_trd Itax_rate_mwshock_pt Isjt_tax_rate_mwshock_pt

global hetero_lgini_grain_trd Ilgini_mwshock_pt Isjt_lgini_mwshock_pt
	
keep occurrence latitude longitude year cell_id ///
	${hetero_credit_dummy} ${hetero_grain_trd_dummy} ///
	${hetero_agr_commerce_credit} ${hetero_railways_credit} ///
	${hetero_tax_rate_credit} ${hetero_lgini_credit} ///
	${hetero_agr_commerce_grain_trd} ${hetero_railways_grain_trd} ///
	${hetero_tax_rate_grain_trd} ${hetero_lgini_grain_trd} 
	
replace occurrence = occurrence * 100	
				
***************** Panel A: The effects of local economic shock *****************	
		
global vars_report Ish_jews_credit_lshock_pt Ish_jews_credit_lshock Ish_jews_credit_pol_turmoil ///
	Iagr_com_lshock_pt Iagr_com_pol_turmoil Isjc_agr_com_lshock ///
	Id2rail_lshock_pt Id2rail_pol_turmoil Isjc_d2rail_lshock_pt ///
	Ilgini_lshock_pt Ilgini_pol_turmoil Isjc_lgini_lshock_pt ///
	Itax_rate_lshock_pt Itax_rate_pol_turmoil Isjc_tax_rate_lshock_pt ///

	** 1

	reg occurrence ${hetero_credit_dummy} ${hetero_agr_commerce_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_agr_commerce_credit}, ${acreg_option}
	outreg2 using table_a15_panel_A_occurrence_results_heterogenoeus_local_shocks_quadruple.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace
				
	** 2
	
	reg occurrence ${hetero_credit_dummy} ${hetero_railways_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_railways_credit}, ${acreg_option}
	outreg2 using table_a15_panel_A_occurrence_results_heterogenoeus_local_shocks_quadruple.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append

	** 3
	
	reg occurrence ${hetero_credit_dummy} ${hetero_lgini_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_lgini_credit}, ${acreg_option}
	outreg2 using table_a15_panel_A_occurrence_results_heterogenoeus_local_shocks_quadruple.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append

	** 4
	
	reg occurrence ${hetero_credit_dummy} ${hetero_tax_rate_credit} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_credit_dummy} ${hetero_tax_rate_credit}, ${acreg_option}
	outreg2 using table_a15_panel_A_occurrence_results_heterogenoeus_local_shocks_quadruple.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append
		
************** Panel B: The effects of marketwide economic shock ***************
	
global vars_report Ish_jews_trd_gr_mwshock_pt ///	
	${hetero_agr_commerce_grain_trd} ${hetero_railways_grain_trd} ///
	${hetero_lgini_grain_trd} ${hetero_tax_rate_grain_trd} 
	
	** 1
	
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_agr_commerce_grain_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_agr_commerce_grain_trd}, ${acreg_option}
	outreg2 using table_a15_panel_B_occurrence_results_heterogenoeus_marketwide_shocks_quadruple.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label replace
			
	** 2
	
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_railways_grain_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_railways_grain_trd}, ${acreg_option}
	outreg2 using table_a15_panel_B_occurrence_results_heterogenoeus_marketwide_shocks_quadruple.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append

	** 3
			
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_lgini_grain_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_lgini_grain_trd}, ${acreg_option}
	outreg2 using table_a15_panel_B_occurrence_results_heterogenoeus_marketwide_shocks_quadruple.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append

	** 4
	
	reg occurrence ${hetero_grain_trd_dummy} ${hetero_tax_rate_grain_trd} ///
		${year_FE} ${cell_FE}, cluster(cell_id)
	scalar r_squared = e(r2)
	
	sum occurrence if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg occurrence ${hetero_grain_trd_dummy} ${hetero_tax_rate_grain_trd}, ${acreg_option}
	outreg2 using table_a15_panel_B_occurrence_results_heterogenoeus_marketwide_shocks_quadruple.xls, ///
		tex(frag) excel bdec(2) tdec(2) sdec(2) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("occurrence, of pogroms") ${add_stat} nonotes nocon nor2 label append
