
set more off
clear 
version 14	

cd "$tables"

*********** Table A5: Local temperature shocks and log of grain yield **********

use "$data/grain_price_harvest_complete_data_gubernia.dta", clear

run "$do_files/ado_files/acreg.ado"

global year_FE i.year
global gubernia_FE i.gub_id

global acreg_option id(gub_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_gub} ///
	pfe1(gub_id) pfe2(year)
	
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)

lab var lshock "Hot spring (Local econ shock)"

keep year gub_id latitude longitude log_grain_harvest ///
	lshock cold_sp5 hot_su5 cold_su5 ///
	hot_au5 cold_au5 hot_wi5 cold_wi5

global vars_report lshock cold_sp5 hot_su5 cold_su5 ///
	hot_au5 cold_au5 hot_wi5 cold_wi5
		
	** 1
	
	reg log_grain_harvest lshock ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_harvest lshock, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 replace

	** 2
	
	reg log_grain_harvest cold_sp5 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg log_grain_harvest cold_sp5, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append
		
	** 3
	
	reg log_grain_harvest hot_su5 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg log_grain_harvest hot_su5, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append
		
	** 4
	
	reg log_grain_harvest cold_su5 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg log_grain_harvest cold_su5, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append

	** 5
	
	reg log_grain_harvest hot_au5 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg log_grain_harvest hot_au5, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append

	** 6
	 
	reg log_grain_harvest cold_au5 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg log_grain_harvest cold_au5, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append
				
	** 7
	
	reg log_grain_harvest hot_wi5 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg log_grain_harvest hot_wi5, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append

	** 8
	
	reg log_grain_harvest cold_wi5 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg log_grain_harvest cold_wi5, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append
		
	** 9
	
	reg log_grain_harvest lshock cold_sp5 hot_su5 cold_su5 hot_au5 cold_au5 ///
		hot_wi5 cold_wi5 ${year_FE} ${gubernia_FE}, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_harvest if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)

	acreg log_grain_harvest lshock cold_sp5 hot_su5 cold_su5 ///
		hot_au5 cold_au5 hot_wi5 cold_wi5, ${acreg_option}
	outreg2 using table_a5_log_grain_yield_temperature_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) ///
		ctitle("log grain harvest") ${add_stat} nonotes nocon label nor2 append
