
set more off
clear 
version 14

cd "$tables"

** Table A7: Grain yield and grain price and robustness of the definitions of **
********************* local and marketwide economic shocks *********************

use "$data/grain_price_harvest_complete_data_gubernia.dta", clear
	
run "$do_files/ado_files/acreg.ado"

global acreg_option id(gub_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_gub} ///
	pfe1(gub_id) pfe2(year)
global acreg_option_wo_gub_FE id(gub_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_gub} pfe1(year) 
global acreg_option_wo_FE id(gub_id) time(year) spatial ///
	latitude(latitude) longitude(longitude) ${cutoff_gub} 
		
global add_stat adds(R-squared, r_squared, ///
	Mean of dependent var., mean_outcome, s.d. of dependent var., sd_outcome)
	
keep gub_id year latitude longitude ///
	log_grain_price log_grain_harvest lshock lshock_lag1 lshock_lag2 ///
	Isg_lshock Isg_lshock_lag1 Isg_lshock_lag2 ///
	mwshock pol_turmoil Ipol_turmoil_mwshock ///
	suitable_grain log_grain_price_lag1 log_grain_price_lag2
	
global vars_report log_grain_harvest lshock lshock_lag1 lshock_lag2 ///
	Isg_lshock Isg_lshock_lag1 Isg_lshock_lag2 ///
	mwshock pol_turmoil Ipol_turmoil_mwshock ///
	suitable_grain log_grain_price_lag1 log_grain_price_lag2
	
	** 1
  	
	reg log_grain_price log_grain_harvest, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price log_grain_harvest, ${acreg_option_wo_FE}
	outreg2 using table_a7_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 replace
	
	** 2
	
	reg log_grain_price log_grain_harvest i.year i.gub_id if year >= 1864, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price log_grain_harvest if year >= 1864, ${acreg_option}
	outreg2 using table_a7_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append
		
	** 3
	
	reg log_grain_price lshock Isg_lshock ///
		lshock_lag1 Isg_lshock_lag1 ///
		lshock_lag2 Isg_lshock_lag2 ///
		log_grain_price_lag1 suitable_grain i.year, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price lshock Isg_lshock ///
		lshock_lag1 Isg_lshock_lag1 ///
		lshock_lag2 Isg_lshock_lag2 ///
		log_grain_price_lag1 suitable_grain, ${acreg_option_wo_gub_FE}
	outreg2 using table_a7_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append
	
	** 4
	
	reg log_grain_price mwshock log_grain_price_lag2, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price mwshock log_grain_price_lag2, ${acreg_option_wo_FE}
	outreg2 using table_a7_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append
	
	** 5
	
	reg log_grain_price mwshock pol_turmoil log_grain_price_lag2, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price mwshock pol_turmoil log_grain_price_lag2, ${acreg_option_wo_FE}
	outreg2 using table_a7_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append
	
	** 6
	
	reg log_grain_price mwshock pol_turmoil Ipol_turmoil_mwshock log_grain_price_lag2, cluster(gub_id)
	scalar r_squared = e(r2)
	
	sum log_grain_price if e(sample)
	scalar mean_outcome = r(mean)
	scalar sd_outcome = r(sd)
	
	acreg log_grain_price mwshock pol_turmoil Ipol_turmoil_mwshock log_grain_price_lag2, ${acreg_option_wo_FE}
	outreg2 using table_a7_grain_yield_price_local_macro_shocks.xls, ///
		excel tex(frag) bdec(3) tdec(3) sdec(3) keep(${vars_report}) sortvar(${vars_report}) ///
		ctitle("log grain price") ${add_stat} nonotes nocon label nor2 append
