
clear all
set maxvar 32000
set matsize 10000

**********************************************************************************
* Please set as the stata working directory the folder of the replication files  *
**********************************************************************************

cd "Your_directory/REStud_GSZ_pogroms_replication"

** Creates the folders to save intermediary data and output folders,
** and sets globals for data folder, do files folder, and output folders

if "`c(os)'" == "MacOSX" {
	shell mkdir -p "`c(pwd)'/output_figures"
	shell mkdir -p "`c(pwd)'/output_tables"
	shell mkdir -p "`c(pwd)'/data/data_generated"
	}

if "`c(os)'" == "Windows" {
	shell mkdir "`c(pwd)'/output_figures"
	shell mkdir "`c(pwd)'/output_tables"
	shell mkdir "`c(pwd)'/data/data_generated"
	}
	
global data = "`c(pwd)'/data"
global figures = "`c(pwd)'/output_figures"
global tables = "`c(pwd)'/output_tables"
global do_files "`c(pwd)'/do_files"	

** Installs the necessary third-party programs **

capture: ssc install sutex
capture: ssc install outreg2
capture: ssc install ivreg2
capture: ssc install hdfe
capture: ssc install cibar
capture: net install grc1leg, all from(http://www.stata.com/users/vwiggins)
capture: ssc install cdfplot
capture: ssc install semipar

** Builds the matching sample data that will be used in Table 8 and Table A10 **

run "$do_files/pogrom_data_neighbors_construction.do"
run "$do_files/pogrom_data_neighbors_construction_sample_t1.do"
run "$do_files/pogrom_data_neighbors_construction_sample_t2.do"

** Defines globals for Conley correction cutoffs **

global cutoff_gub dist(250) lag(1) hac
global cutoff_grid dist(100) lag(1) hac
global cutoff_grid1degree dist(200) lag(1) hac
global cutoff_uezd dist(100) lag(1) hac
		
** Tables and Figures in the main text **

run "$do_files/results_table_1.do"
run "$do_files/results_table_2.do"
run "$do_files/results_table_3.do"
run "$do_files/results_table_4.do"
run "$do_files/results_table_5.do"
run "$do_files/results_table_6.do"
run "$do_files/results_table_7.do"
run "$do_files/results_table_8.do"
run "$do_files/results_table_9.do"
run "$do_files/results_table_10.do"
run "$do_files/results_table_11.do"
run "$do_files/results_table_12.do"

run "$do_files/results_figure_2.do"
run "$do_files/results_figure_3.do"
run "$do_files/results_figure_4.do"
run "$do_files/results_figure_5.do"

** Tables and figures in the Online Appendix **

run "$do_files/results_table_A1.do"
run "$do_files/results_table_A4.do"
run "$do_files/results_table_A5.do"
run "$do_files/results_table_A6.do"
run "$do_files/results_table_A7.do"
run "$do_files/results_table_A8.do"
run "$do_files/results_table_A9.do"
run "$do_files/results_table_A10.do"
run "$do_files/results_table_A11.do"
run "$do_files/results_table_A12.do"
run "$do_files/results_table_A13.do"
run "$do_files/results_table_A14.do"
run "$do_files/results_table_A15.do"

run "$do_files/results_figure_A4.do"
run "$do_files/results_figure_A5.do"
run "$do_files/results_figure_A8.do"
run "$do_files/results_figure_A9.do"
run "$do_files/results_figure_A10.do"
run "$do_files/results_figure_A11.do"
run "$do_files/results_figure_A12.do"
run "$do_files/results_figure_A13.do"
run "$do_files/results_figure_A14.do"
run "$do_files/results_figure_A15.do"
